@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Вградено съобщение %s",
     "Important mail" : "Важна поща",
+    "No message found yet" : "Все още няма намерено съобщение",
+    "Set up an account" : "Създаване на профил",
     "Unread mail" : "Непрочетена поща",
     "Important" : "Важно",
     "Work" : "Служебен",
@@ -91,6 +93,8 @@ OC.L10N.register(
     "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
     "Show keyboard shortcuts" : "Показване на клавишни комбинации",
     "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
+    "Newest" : "Най-новият",
+    "Oldest" : "Най-старият",
     "Looking for a way to encrypt your emails?" : "Търсите ли начин да шифровате имейлите си?",
     "Install Mailvelope browser extension here" : "Инсталирайте тук разширението за браузър Mailvelope",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
@@ -155,8 +159,6 @@ OC.L10N.register(
     "_{count} attachment_::_{count} attachments_" : ["{count} прикачени файлове","{count} прикачени файлове"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прикачените файлове надвишават разрешения размер на прикачени файлове от {size}. Моля, вместо това да споделите файловете чрез връзка.","Прикачените файлове надвишават разрешения размер на прикачени файлове от {size}. Моля, вместо това да споделите файловете чрез връзка."],
     "Confirm" : "Потвърдете",
-    "No message found yet" : "Все още няма намерено съобщение",
-    "Set up an account" : "Създаване на профил",
     "Plain text" : "Обикновен текст",
     "Rich text" : "Форматиран текст",
     "No messages in this mailbox" : "Няма съобщения в тази пощенска кутия",
@@ -246,7 +248,6 @@ OC.L10N.register(
     "Forward message as attachment" : "Препращане на съобщението като прикачен файл",
     "View source" : "Преглед на източника",
     "Download thread data for debugging" : "Изтегля данните за нишките за отстраняване на грешки",
-    "Message source" : "Източник на съобщение",
     "Message body" : "Тяло на съобщението",
     "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Предупреждение: S/MIME подписът на това съобщение не е потвърден. Възможно е подателят да се представя /въплъщава/ за някого!",
     "Import into calendar" : "Импортиране в календар",
@@ -348,7 +349,7 @@ OC.L10N.register(
     "Search in mailbox" : "Търсене в пощенската кутия",
     "Close" : "Затваряне",
     "Search parameters" : "Параметри на търсенето",
-    "Search term" : "Термин за търсене",
+    "Body" : "Съдържание",
     "Pick a start date" : "Избор на начална дата",
     "Pick an end date" : "Избор на крайна дата",
     "Select senders" : "Избор на податели",
@@ -378,17 +379,17 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Подписът ви е по-голям от 2 MB. Това може да се отрази на работата на  вашия редактор.",
     "Save signature" : "Запис на подпис",
     "Place signature above quoted text" : "Поставяне на подпис над цитирания текст",
-    "Add default tags" : "Добавяне на етикети по подразбиране",
-    "Rename tag" : "Преименуване на етикет",
+    "Delete tag" : "Изтрий таг",
     "Saving new tag name …" : "Запазва се името на нов етикет …",
     "Set tag" : "Задаване на етикет",
     "Unset tag" : "Отмяна на етикет",
+    "An error occurred, unable to rename the tag." : "Възникна грешка, не може да се преименува етикет.",
+    "Add default tags" : "Добавяне на етикети по подразбиране",
     "Add tag" : "Добавяне на етикет",
     "Saving tag …" : "Записване на етикет ...",
     "Tag name is a hidden system tag" : "Името на етикета е скрит системен етикет",
     "Tag already exists" : "Етикетът вече съществува",
     "An error occurred, unable to create the tag." : "Възникна грешка, не може да се създаде етикет.",
-    "An error occurred, unable to rename the tag." : "Възникна грешка, не може да се преименува етикет.",
     "Loading thread" : "Зареждане на нишка",
     "Not found" : "Не е намерен",
     "Could not load your message thread" : " Нишката на вашето съобщение не можа да се зареди",
@@ -400,6 +401,7 @@ OC.L10N.register(
     "Mark as read" : "Маркиране като прочетено",
     "Archive message" : "Архивиране на съобщение",
     "Delete message" : "Изтриване на съобщението",
+    "Message source" : "Източник на съобщение",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Прекратяването на абонамента ще спре всички съобщения от пощенския списък {sender}",
     "Encrypted & verified " : "Криптирано и потвърдено",
     "Signature verified" : "Подписът е потвърден",
