@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Zapouzdřená zpráva %s",
     "Important mail" : "Důležité e-maily",
+    "No message found yet" : "Zatím nenalezeny žádné zprávy",
+    "Set up an account" : "Nastavit si účet",
     "Unread mail" : "Nepřečtené e-maily",
     "Important" : "Důležité",
     "Work" : "Pracovní",
@@ -10,7 +12,7 @@ OC.L10N.register(
     "To Do" : "Úkoly",
     "Later" : "Později",
     "Mail" : "E-mail",
-    "You are reaching your mailbox quota limit for {account}" : "Blížíte se limitu kvóty objemu vaší e-mailové schránky u účtu {account}",
+    "You are reaching your mailbox quota limit for {account_email}" : "Blížíte se limitu kvóty objemu dat vaší e-mailové schránky u účtu {account_email}",
     "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Nyní využíváte {percentage} úložiště vaší e-mailové schránky. Uvolněte nějaké místo smazáním nepotřebných e-mailů.",
     "Mails" : "E-maily",
     "💌 A mail app for Nextcloud" : "💌 E-mailová aplikace pro Nextcloud",
@@ -86,6 +88,7 @@ OC.L10N.register(
     "Trusted senders" : "Důvěryhodní odesílatelé",
     "Mail server" : "E-mailový server",
     "Sieve filter server" : "Filtrovací server sieve",
+    "Mailbox search" : "Hledání ve schránce",
     "Update alias" : "Aktualizovat alternativní název",
     "Rename alias" : "Přejmenovat alternativní název",
     "Show update alias form" : "Zobrazit formulář pro aktualizaci alternativního názvu",
@@ -101,8 +104,11 @@ OC.L10N.register(
     "Register as application for mail links" : "Zaregistrovat jako aplikaci pro obsluhu e-mailových odkazů",
     "Show keyboard shortcuts" : "Zobrazit klávesové zkratky",
     "Manage S/MIME certificates" : "Spravovat S/MIME certifikáty",
+    "Newest" : "Nejnovější",
+    "Oldest" : "Nejstarší",
     "Looking for a way to encrypt your emails?" : "Hledáte způsob jak šifrovat své e-maily?",
     "Install Mailvelope browser extension here" : "Nainstalujte si rozšíření pro webový prohlížeč Mailvelope zde",
+    "Search in the body of messages in priority Inbox" : "Hledat v těle zpráv v prioritní schránce",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Povolit aplikaci shromažďovat data o vaší interakci s ní. Na základě těchto dat se aplikace přizpůsobí vašim preferencím. Data budou ukládána pouze lokálně.",
     "Put my text to the bottom of a reply instead of on top of it." : "Můj text umístit na konec odpovědi namísto na její začátek.",
     "Automatically classify importance of new email" : "Automaticky klasifikovat důležitost nového e-mailu",
@@ -168,8 +174,9 @@ OC.L10N.register(
     "Close composer" : "Zavřít dialog psaní",
     "Untitled message" : "Zpráva bez názvu",
     "Confirm" : "Potvrdit",
-    "No message found yet" : "Zatím nenalezeny žádné zprávy",
-    "Set up an account" : "Nastavit si účet",
+    "The tag will be deleted from all messages." : "Štítek bude smazán ze všech zpráv.",
+    "Tag: {name} deleted" : "Štítek: {name} smazán",
+    "An error occurred, unable to delete the tag." : "Došlo k chybě, štítek se nepodařilo smazat.",
     "Plain text" : "Neformátovaný text",
     "Rich text" : "Formátovaný text",
     "No messages in this mailbox" : "V této schránce nejsou žádné zprávy",
@@ -188,6 +195,7 @@ OC.L10N.register(
     "Select" : "Vybrat",
     "Edit tags" : "Upravit štítky",
     "Snooze" : "Odložit",
+    "Unsnooze" : "Zrušit odložení",
     "Move thread" : "Přesunout vlákno",
     "Archive thread" : "Zaarchivovat vlákno",
     "Delete thread" : "Smazat vlákno",
@@ -209,6 +217,8 @@ OC.L10N.register(
     "Could not archive message" : "Zprávu se nedaří zaarchivovat",
     "Thread was snoozed" : "Vlákno bylo odloženo",
     "Could not snooze thread" : "Vlákno se nepodařilo odložit",
+    "Thread was unsnoozed" : "Odložení vlákna bylo zrušeno",
+    "Could not unsnooze thread" : "Nepodařilo se zrušit odložení vlákna",
     "Forward" : "Přeposlat",
     "Load more" : "Načíst více",
     "_Mark {number} unread_::_Mark {number} unread_" : ["Označit {number} jako nepřečtený","Označit {number} jako nepřečtené","Označit {number} jako nepřečtených","Označit {number} jako nepřečtené"],
@@ -217,7 +227,10 @@ OC.L10N.register(
     "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Označit {number} jako nedůležité","Označit {number} jako nedůležité","Označit {number} jako nedůležité","Označit {number} jako nedůležité"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Odebrat {number} z oblíbených","Odebrat {number} z oblíbených","Odebrat {number} z oblíbených","Odebrat {number} z oblíbených"],
     "_Favorite {number}_::_Favorite {number}_" : ["Přidat {number} do oblíbených","Přidat {number} do oblíbených","Přidat {number} do oblíbených","Přidat {number} do oblíbených"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu","Označit {number} jako nevyžádanou poštu"],
+    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu","Označit {number} jako chtěnou poštu"],
     "_Unselect {number}_::_Unselect {number}_" : ["Zrušit výběr {number}","Zrušit výběr {number}","Zrušit výběr {number}","Zrušit výběr {number}"],
+    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Upravit štítky pro {number}","Upravit štítky pro {number}","Upravit štítky pro {number}","Upravit štítky pro {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Přesunout {number} vlákno","Přesunout {number} vlákna","Přesunout {number} vláken","Přesunout {number} vlákna"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Přeposlat {number} jako přílohu","Přeposlat {number} jako přílohy","Přeposlat {number} jako přílohy","Přeposlat {number} jako přílohy"],
     "_Delete {number} thread_::_Delete {number} threads_" : ["Smazat {number} vlákno","Smazat {number} vlákna","Smazat {number} vláken","Smazat {number} vlákna"],
@@ -267,15 +280,16 @@ OC.L10N.register(
     "Forward message as attachment" : "Přeposlat zprávu jako přílohu",
     "View source" : "Zobrazit zdroj",
     "Download thread data for debugging" : "Stáhnout si data vlákna pro účely ladění",
-    "Message source" : "Zdrojový kód zprávy",
     "Message was snoozed" : "Zpráva byla odložena",
     "Could not snooze message" : "Zprávu se nepodařilo odložit",
+    "Message was unsnoozed" : "Odložení zprávy bylo zrušeno",
+    "Could not unsnooze message" : "Nepodařilo se zrušit odložení zprávy",
     "Message body" : "Tělo zprávy",
     "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Varování: S/MIME podpis této zprávy není ověřen. Odesilatel  se může pokoušet vystupovat jako někdo jiný!",
     "Import into calendar" : "Importovat do kalendáře",
     "Download attachment" : "Stáhnout si přílohu",
     "Save to Files" : "Uložit do Souborů",
-    "Unnamed" : "Nepojmenovaný",
+    "Unnamed" : "Bez názvu",
     "Embedded message" : "Zapouzdřená zpráva",
     "Next week – {timeLocale}" : "Příští týden – {timeLocale}",
     "Choose a folder to store the attachment in" : "Vyberte složku pro uložení přílohy",
@@ -303,6 +317,7 @@ OC.L10N.register(
     "Quota" : "Kvóta",
     "Show only subscribed mailboxes" : "Zobrazit pouze přihlášené poštovní schránky",
     "Add mailbox" : "Přidat schránku",
+    "Mailbox name" : "Název schránky",
     "Saving" : "Ukládá se",
     "Move up" : "Přesunout výše",
     "Move down" : "Přesunout dolů",
@@ -349,8 +364,11 @@ OC.L10N.register(
     "Message saved" : "Zpráva uložena",
     "Failed to save message" : "Zprávu se nepodařilo uložit",
     "Failed to save draft" : "Koncept se nepodařilo uložit",
+    "attachment" : "příloha",
+    "attached" : "přiloženo",
     "No sent mailbox configured. Please pick one in the account settings." : "Není nastavená žádná složka pro odchozí. Zvolte nějakou v nastavení účtu.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "V kolonkách Pro a Skrytá kopie se snažíte poslat opravdu mnoha příjemcům. Zvažte použití Skryté kopie a nesdělování tak adres příjemců všem.",
+    "You mentioned an attachment. Did you forget to add it?" : "Zmínili jste přílohu. Nezapomněli jste ji přidat?",
     "Message discarded" : "Zpráva zahozena",
     "Could not discard message" : "Zprávu se nepodařilo zahodit",
     "Welcome to {cloudName} Mail" : "Vítejte v {cloudName} Poště",
@@ -378,7 +396,9 @@ OC.L10N.register(
     "Search in mailbox" : "Hledat ve schránce",
     "Close" : "Zavřít",
     "Search parameters" : "Parametry hledání",
-    "Search term" : "Hledat pojem",
+    "Search subject" : "Hledat předmět",
+    "Body" : "Těle textu",
+    "Search body" : "Hledat v těle zprávy",
     "Pick a start date" : "Vybrat datum začátku",
     "Pick an end date" : "Vybrat datum konce",
     "Select senders" : "Vybrat odesilatele",
@@ -392,6 +412,7 @@ OC.L10N.register(
     "Clear" : "Vyčistit",
     "Search" : "Hledat",
     "Date" : "Datum",
+    "Enable mail body search" : "Zapnout hledání v těle zprávy",
     "Disabled" : "Vypnuto",
     "Enabled" : "Zapnuto",
     "Sieve Host" : "Stroj se sieve",
@@ -410,17 +431,18 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Váš podpis je větší než 2 MB. To může zpomalovat editor.",
     "Save signature" : "Uložit podpis",
     "Place signature above quoted text" : "Vložit podpis nad citovaný text",
-    "Add default tags" : "Přidat výchozí štítky",
-    "Rename tag" : "Přejmenovat štítek",
+    "Edit name or color" : "Upravit název nebo barvu",
+    "Delete tag" : "Smazat štítek",
     "Saving new tag name …" : "Ukládání nového názvu štítku…",
     "Set tag" : "Nastavit štítek",
     "Unset tag" : "Zrušit nastavení štítku",
+    "An error occurred, unable to rename the tag." : "Došlo k chybě, štítek se nedaří přejmenovat.",
+    "Add default tags" : "Přidat výchozí štítky",
     "Add tag" : "Přidat štítek",
     "Saving tag …" : "Ukládání štítku…",
     "Tag name is a hidden system tag" : "Takto nazvaný štítek už existuje v podobě skrytého systémového štítku",
     "Tag already exists" : "Štítek už existuje",
     "An error occurred, unable to create the tag." : "Došlo k chybě, štíte se nepodařilo vytvořit.",
-    "An error occurred, unable to rename the tag." : "Došlo k chybě, štítek se nedaří přejmenovat.",
     "Select calendar" : "Vybrat kalendář",
     "No calendars with task list support" : "Nejsou zde žádné kalendáře, které by podporovaly seznam úkolů",
     "Task created" : "Úkol vytvořen",
@@ -437,6 +459,7 @@ OC.L10N.register(
     "Mark as read" : "Označit jako přečtené",
     "Archive message" : "Zaarchivovat zprávu",
     "Delete message" : "Smazat zprávu",
+    "Message source" : "Zdrojový kód zprávy",
     "Unsubscribe via link" : "Zrušit (prostřednictvím odkazu) přihlášení se k odběru",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Zrušení přihlášení se k odběru zastaví veškeré zprávy  z e-mailové distribuce {sender}",
     "Send unsubscribe email" : "Odeslat e-mail ohledně zrušení odběru",
@@ -542,6 +565,8 @@ OC.L10N.register(
     "Host" : "Hostitel",
     "Port" : "Port",
     "SMTP" : "SMTP",
+    "Master password" : "Hlavní heslo",
+    "Use master password" : "Použít hlavní heslo",
     "Sieve" : "Sieve",
     "Enable sieve integration" : "Zapnout napojení na sieve",
     "LDAP aliases integration" : "Napojení na LDAP alternativní názvy",
