@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Indlejret besked %s",
     "Important mail" : "Vigtig mail",
+    "No message found yet" : "Ingen beskeder",
+    "Set up an account" : "Opret en konto",
     "Unread mail" : "Ulæst mail",
     "Important" : "Vigtig",
     "Work" : "Arbejde",
@@ -111,6 +113,7 @@ OC.L10N.register(
     "Discard & close draft" : "Kassér og luk kladde",
     "Upload attachment" : "Upload vedhæftning",
     "Add attachment from Files" : "Vedhæft fra filer",
+    "Smart picker" : "Smart Vælger",
     "Send later" : "Send senere",
     "Enable formatting" : "Aktiver formatering",
     "Disable formatting" : "Deaktiver formatering",
@@ -139,8 +142,6 @@ OC.L10N.register(
     "_{count} attachment_::_{count} attachments_" : ["{count} vedhæftet fil","{count} vedhæftede filer"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Den vedhæftede fil overskrider den tilladte størrelse på vedhæftede filer på {size}. Del venligst filen via link i stedet.","De vedhæftede filer overskrider den tilladte størrelse på vedhæftede filer på {size}. Del venligst filerne via link i stedet."],
     "Confirm" : "Bekræft",
-    "No message found yet" : "Ingen beskeder",
-    "Set up an account" : "Opret en konto",
     "Plain text" : "Klartekst",
     "Rich text" : "Formateret tekst",
     "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
@@ -220,7 +221,6 @@ OC.L10N.register(
     "Move message" : "Flyt besked",
     "Forward message as attachment" : "Videresend besked som vedhæftet fil",
     "View source" : "Vis kildekode",
-    "Message source" : "Beskedens kildekode",
     "Import into calendar" : "Importere til kalender",
     "Download attachment" : "Hent vedhæftning",
     "Save to Files" : "Gem til filer",
@@ -275,7 +275,7 @@ OC.L10N.register(
     "Search in mailbox" : "Søg i postkasse",
     "Close" : "Luk",
     "Search parameters" : "Søgeparametre",
-    "Search term" : "Søgeterm",
+    "Body" : "Krop",
     "Pick a start date" : "Vælg en startdato",
     "Pick an end date" : "Vælg en slutdato",
     "Tags" : "Mærker",
@@ -297,6 +297,7 @@ OC.L10N.register(
     "Mark as unread" : "Marker som ulæst",
     "Mark as read" : "Marker som læst",
     "Delete message" : "Slet besked",
+    "Message source" : "Beskedens kildekode",
     "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meddelelse indeholder en verificeret digital S/MIME-signatur. Meddelelsen er ikke ændret, siden den blev sendt.",
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME-signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
     "Remove" : "Fjern",
