@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Eingebettete Nachricht %s",
     "Important mail" : "Wichtige E-Mail",
+    "No message found yet" : "Keine Nachrichten gefunden",
+    "Set up an account" : "Konto einrichten",
     "Unread mail" : "Ungelesene E-Mail",
     "Important" : "Wichtig",
     "Work" : "Arbeit",
@@ -10,6 +12,8 @@ OC.L10N.register(
     "To Do" : "Offen",
     "Later" : "Später",
     "Mail" : "E-Mail",
+    "You are reaching your mailbox quota limit for {account_email}" : "Du erreichst die Grenze deines Postfach-Kontingents für {account_email}",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Du nutzt derzeit {percentage} deines Postfachspeichers. Bitte schaffe etwas Platz, indem du nicht benötigte E-Mails löscht.",
     "Mails" : "E-Mails",
     "💌 A mail app for Nextcloud" : "💌 Eine E-Mail-App für Nextcloud",
     "Your session has expired. The page will be reloaded." : "Deine Sitzung ist abgelaufen. Seite wird neu geladen.",
@@ -17,6 +21,8 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Gesendete Nachrichten werden gespeichert in:",
     "Deleted messages are moved in:" : "Gelöschte Nachrichten werden verschoben nach:",
     "Archived messages are moved in:" : "Archivierte Nachrichten werden verschoben nach:",
+    "Snoozed messages are moved in:" : "Zurückgestellte Nachrichten werden verschoben nach:",
+    "Junk messages are saved in:" : "Spam-Nachrichten werden gespeichert in:",
     "Auto" : "Automatisch",
     "Name" : "Name",
     "Mail address" : "E-Mail-Adresse",
@@ -51,7 +57,9 @@ OC.L10N.register(
     "Password required" : "Passwort erforderlich",
     "Testing authentication" : "Prüfe Authentifizierung",
     "Awaiting user consent" : "Warte auf Zustimmung des Benutzers",
+    "Account created. Please follow the pop-up instructions to link your Google account" : "Konto erstellt. Bitte befolge die Pop-up-Anweisungen, um dein Google-Konto zu verknüpfen",
     "Loading account" : "Lade Konto",
+    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konto aktualisiert. Bitte befolge die Pop-up-Anweisungen, um dein Google-Konto erneut zu verbinden",
     "Account updated" : "Konto aktualisiert",
     "IMAP server is not reachable" : "IMAP-Server ist nicht erreichbar.",
     "SMTP server is not reachable" : "SMTP-Server ist nicht erreichbar.",
@@ -60,6 +68,7 @@ OC.L10N.register(
     "IMAP connection failed" : "IMAP-Verbindung fehlgeschlagen",
     "SMTP connection failed" : "SMTP-Verbindung fehlgeschlagen",
     "Authorization pop-up closed" : "Anmeldungs-Pop-up wurde geschlossen",
+    "Configuration discovery temporarily not available. Please try again later." : "Konfigurationserkennung vorübergehend nicht verfügbar. Bitte versuche es später noch einmal.",
     "There was an error while setting up your account" : "Bei der Einrichtung deines Kontos ist ein Fehler aufgetreten.",
     "Account settings" : "Konto-Einstellungen",
     "Aliases" : "Aliasse",
@@ -69,6 +78,9 @@ OC.L10N.register(
     "Writing mode" : "Schreibmodus",
     "Preferred writing mode for new messages and replies." : "Bevorzugter Schreibmodus für neue Nachrichten und Antworten.",
     "Default folders" : "Standardordner",
+    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Die Ordner, die für Entwürfe, gesendete Nachrichten, gelöschte Nachrichten, archivierte Nachrichten und Spam-Nachrichten verwendet werden sollen.",
+    "Automatic trash deletion" : "Automatische Papierkorblöschung",
+    "Days after which messages in Trash will automatically be deleted:" : "Tage, nach denen Nachrichten im Papierkorb automatisch gelöscht werden:",
     "Autoresponder" : "Automatische Antworten",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisierte Antwort auf eingehende Nachrichten. Wenn dir jemand mehrere Nachrichten schickt, wird diese automatische Antwort höchstens einmal alle 4 Tage gesendet.",
     "Please connect to a sieve server first." : "Bitte stelle zunächst eine Verbindung zu einem Sieve-Server her.",
@@ -76,6 +88,7 @@ OC.L10N.register(
     "Trusted senders" : "Vertrauenswürdige Absender",
     "Mail server" : "Mail-Server",
     "Sieve filter server" : "Sieve-Filterserver",
+    "Mailbox search" : "Postfach durchsuchen",
     "Update alias" : "Alias aktualisieren",
     "Rename alias" : "Alias umbenennen",
     "Show update alias form" : "Update-Alias-Formular anzeigen",
@@ -91,8 +104,11 @@ OC.L10N.register(
     "Register as application for mail links" : "Als Anwendung für Mail-Links registrieren",
     "Show keyboard shortcuts" : "Tastaturkürzel anzeigen",
     "Manage S/MIME certificates" : "S/MIME Zertifikate verwalten",
+    "Newest" : "Neueste",
+    "Oldest" : "Älteste",
     "Looking for a way to encrypt your emails?" : "Suchst du nach einer Möglichkeit, deine E-Mails zu verschlüsseln?",
     "Install Mailvelope browser extension here" : "Die Mailvelope-Browsererweiterung hier installieren",
+    "Search in the body of messages in priority Inbox" : "Im Nachrichtentext im Prioritäts-Posteingang suchen",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Erlaube der App, Daten über deine Interaktionen zu sammeln. Basierend auf diesen Daten passt sich die App an deine Vorlieben an. Die Daten werden nur lokal gespeichert.",
     "Put my text to the bottom of a reply instead of on top of it." : "Füge meinen Text am Ende einer Antwort anstatt darüber. ",
     "Automatically classify importance of new email" : "Automatisches Einordnen der Wichtigkeit neuer E-Mails",
@@ -154,10 +170,13 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Datei auswählen welche als Link geteilt wird",
     "_{count} attachment_::_{count} attachments_" : ["{count} Anhang","{count} Anhänge"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Der Anhang überschreitet die zulässige Anhangsgröße von {size}. Bitte teilen Sie die Dateien stattdessen über einen Link.","Die Anhänge überschreiten die zulässige Anhangsgröße von {size}. Bitte teile die Dateien stattdessen über einen Link."],
+    "Expand composer" : "Erstellungsbereich erweitern",
+    "Close composer" : "Erstellungsbereich schließen",
     "Untitled message" : "Nachricht ohne Titel",
     "Confirm" : "Bestätigen",
-    "No message found yet" : "Keine Nachrichten gefunden",
-    "Set up an account" : "Konto einrichten",
+    "The tag will be deleted from all messages." : "Das Schlagwort wird aus allen Nachrichten gelöscht.",
+    "Tag: {name} deleted" : "Schlagwort: {name} gelöscht",
+    "An error occurred, unable to delete the tag." : "Es ist ein Fehler aufgetreten, das Schlagwort konnte nicht gelöscht werden.",
     "Plain text" : "Klartext",
     "Rich text" : "Rich-Text",
     "No messages in this mailbox" : "Keine Nachrichten in diesem Postfach",
@@ -175,20 +194,31 @@ OC.L10N.register(
     "Unselect" : "Abwählen",
     "Select" : "Auswählen",
     "Edit tags" : "Schlagworte bearbeiten",
+    "Snooze" : "Zurückstellen",
+    "Unsnooze" : "Zurückstellung aufheben",
     "Move thread" : "Unterhaltung verschieben",
     "Archive thread" : "Thema archivieren",
     "Delete thread" : "Unterhaltung löschen",
     "More actions" : "Weitere Aktionen",
     "Back" : "Zurück",
+    "Set custom snooze" : "Zurückstellen benutzerdefiniert setzen",
     "Edit as new message" : "Als neue Nachricht bearbeiten",
     "Create event" : "Termin erstellen",
     "Create task" : "Aufgabe erstellen",
     "Download message" : "Nachricht herunterladen",
     "Blind copy recipients only" : "Nur BCC-Empfänger",
     "No subject" : "Kein Betreff",
+    "Set reminder for later today" : "Erinnerung für nachher erstellen",
+    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
+    "Set reminder for this weekend" : "Erinnerung für dieses Wochenende erstellen",
+    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen",
     "No trash mailbox configured" : "Kein Papierkorb-Postfach konfiguriert",
     "Could not delete message" : "Nachricht konnte nicht gelöscht werden",
     "Could not archive message" : "Nachricht konnte nicht archiviert werden",
+    "Thread was snoozed" : "Unterhaltung wurde zurückgestellt",
+    "Could not snooze thread" : "Unterhaltung konnte nicht zurückgestellt werden",
+    "Thread was unsnoozed" : "Zurückstellung der Unterhaltung aufgehoben",
+    "Could not unsnooze thread" : "Zurückstellung der Unterhaltung konnte nicht aufgehoben werden",
     "Forward" : "Weiterleiten",
     "Load more" : "Mehr laden",
     "_Mark {number} unread_::_Mark {number} unread_" : ["{number} als ungelesen markieren","{number} als ungelesen markieren"],
@@ -247,7 +277,10 @@ OC.L10N.register(
     "Forward message as attachment" : "Nachricht als Anhang weiterleiten",
     "View source" : "Quelle ansehen",
     "Download thread data for debugging" : "Thread-Daten zum Debuggen herunterladen",
-    "Message source" : "Nachrichtenquelle",
+    "Message was snoozed" : "Nachricht wurde zurückgestellt",
+    "Could not snooze message" : "Nachricht konnte nicht zurückgestellt werden",
+    "Message was unsnoozed" : "Zurückstellung der Nachricht wurde aufgehoben",
+    "Could not unsnooze message" : "Zurückstellung der Nachricht konnte nicht aufgehoben werden",
     "Message body" : "Nachrichtentext",
     "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Warnung: Die S/MIME-Signatur dieser Nachricht ist nicht bestätigt. Der Absender gibt sich möglicherweise als jemand anderes aus!",
     "Import into calendar" : "In Kalender importieren",
@@ -255,7 +288,9 @@ OC.L10N.register(
     "Save to Files" : "Unter Dateien speichern",
     "Unnamed" : "Unbenannt",
     "Embedded message" : "Eingebettete Nachricht",
+    "Next week – {timeLocale}" : "Nächste Woche – {timeLocale}",
     "Choose a folder to store the attachment in" : "Ordner zum Speichern des Anhangs auswählen",
+    "calendar imported" : "Kalender importiert",
     "View fewer attachments" : "Weniger Anhänge anzeigen",
     "Save all to Files" : "Alles unter Dateien sichern",
     "Download Zip" : "ZIP herunterladen",
@@ -279,6 +314,7 @@ OC.L10N.register(
     "Quota" : "Kontingent",
     "Show only subscribed mailboxes" : "Nur abonnierte Postfächer anzeigen",
     "Add mailbox" : "Postfach hinzufügen",
+    "Mailbox name" : "Postfachname",
     "Saving" : "Speichere",
     "Move up" : "Nach oben verschieben",
     "Move down" : "Nach unten verschieben",
@@ -319,15 +355,20 @@ OC.L10N.register(
     "Sending …" : "Sende …",
     "Warning sending your message" : "Warnung beim Senden der Nachricht",
     "Send anyway" : "Dennoch senden",
+    "Minimize composer" : "Erstellungsbereich minimieren",
     "Edit message" : "Nachricht bearbeiten",
     "Draft" : "Entwurf",
     "Message saved" : "Nachricht gespeichert",
     "Failed to save message" : "Fehler beim Speichern der Nachricht",
     "Failed to save draft" : "Fehler beim Speichern des Entwurfs",
+    "attachment" : "Anhang",
+    "attached" : "angehängt",
     "No sent mailbox configured. Please pick one in the account settings." : "Keine Postfach für gesendete Nachrichten konfiguriert. Bitte wähle eines in den Kontoeinstellungen aus.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du bist im Begriff, an viele Empfänger in den Feldern \"An\" und/oder \"Cc\" zu schreiben. Benutze das Feld \"Bcc\", um die Empfängeradressen zu verbergen.",
+    "You mentioned an attachment. Did you forget to add it?" : "Du hast einen Anhang erwähnt. Hast du vergessen ihn hinzuzufügen?",
     "Message discarded" : "Nachricht verworfen",
     "Could not discard message" : "Nachricht konnte nicht verworfen werden",
+    "Welcome to {cloudName} Mail" : "Willkommen zu {cloudName} Mail",
     "Autoresponder off" : "Automatische Antworten nicht senden",
     "Autoresponder on" : "Automatische Antworten senden",
     "First day" : "Erster Tag",
@@ -352,7 +393,9 @@ OC.L10N.register(
     "Search in mailbox" : "Im Postfach suchen",
     "Close" : "Schließen",
     "Search parameters" : "Suchparameter",
-    "Search term" : "Suchbegriff",
+    "Search subject" : "Thema durchsuchen",
+    "Body" : "Inhalt",
+    "Search body" : "Nachrichtentext durchsuchen",
     "Pick a start date" : "Startdatum wählen",
     "Pick an end date" : "Enddatum wählen",
     "Select senders" : "Absender wählen",
@@ -366,6 +409,7 @@ OC.L10N.register(
     "Clear" : "Löschen",
     "Search" : "Suchen",
     "Date" : "Datum",
+    "Enable mail body search" : "Durchsuchen des Nachrichtentextes aktivieren",
     "Disabled" : "Deaktiviert",
     "Enabled" : "Aktiviert",
     "Sieve Host" : "Sieve-Host",
@@ -379,27 +423,30 @@ OC.L10N.register(
     "Save sieve settings" : "Sieve-Einstellungen speichern",
     "Save sieve script" : "Sieve-Skript speichern",
     "The syntax seems to be incorrect:" : "Die Syntax scheint falsch zu sein:",
+    "This weekend – {timeLocale}" : "Dieses Wochenende – {timeLocale}",
     "Signature …" : "Signatur …",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Deine Signatur ist größer als 2 MB. Dies kann die Leistung deines Editors beeinträchtigen.",
     "Save signature" : "Signatur speichern",
     "Place signature above quoted text" : "Signatur über dem zitierten Text platzieren",
-    "Add default tags" : "Standard-Schlagworte hinzufügen",
-    "Rename tag" : "Schlagwort umbenennen",
+    "Edit name or color" : "Name oder Farbe bearbeiten",
+    "Delete tag" : "Schlagwort löschen",
     "Saving new tag name …" : "Speichere neues Schlagwort …",
     "Set tag" : "Schlagwort setzen",
     "Unset tag" : "Schlagwort entfernen",
+    "An error occurred, unable to rename the tag." : "Es ist ein Fehler aufgetreten. Das Schlagwort konnte nicht umbenannt werden.",
+    "Add default tags" : "Standard-Schlagworte hinzufügen",
     "Add tag" : "Schlagwort hinzufügen",
     "Saving tag …" : "Speichere Schlagwort …",
     "Tag name is a hidden system tag" : "Name des Schlagworts ist ein verstecktes System-Schlagwort.",
     "Tag already exists" : "Schlagwort ist bereits vorhanden",
     "An error occurred, unable to create the tag." : "Es ist ein Fehler aufgetreten. Das Schlagwort konnte nicht erstellt werden.",
-    "An error occurred, unable to rename the tag." : "Es ist ein Fehler aufgetreten. Das Schlagwort konnte nicht umbenannt werden.",
     "Select calendar" : "Kalender auswählen",
     "No calendars with task list support" : "Keine Kalender mit Unterstützung für Aufgabenlisten",
     "Task created" : "Aufgabe erstellt",
     "Could not create task" : "Aufgabe konnte nicht erstellt werden",
     "Loading thread" : "Thema wird geladen",
     "Not found" : "Nicht gefunden",
+    "Summarizing thread failed." : "Zusammenfassen der Unterhaltung ist fehlgeschlagen.",
     "Could not load your message thread" : "Nachrichtenverlauf konnte nicht geöffnet werden",
     "The thread doesn't exist or has been deleted" : "Der Thread existiert nicht oder wurde gelöscht.",
     "Unsubscribe" : "Abmelden",
@@ -409,6 +456,7 @@ OC.L10N.register(
     "Mark as read" : "Als gelesen markieren",
     "Archive message" : "Nachricht archivieren",
     "Delete message" : "Nachricht löschen",
+    "Message source" : "Nachrichtenquelle",
     "Unsubscribe via link" : "Per Link abmelden",
     "Unsubscribing will stop all messages from the mailing list {sender}" : "Die Abmeldung stoppt alle Nachrichten von der Mailingliste {sender}.",
     "Send unsubscribe email" : "Abmelde-E-Mail senden",
@@ -421,6 +469,11 @@ OC.L10N.register(
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Diese Nachricht enthält eine ungeprüfte digitale S/MIME-Signatur. Unter Umständen wurde die Nachricht seit dem Senden verändert oder dem Zertifikat des Absenders wird nicht vertraut.",
     "Unsubscribe request sent" : "Anfrage zum Abmelden gesendet",
     "Could not unsubscribe from mailing list" : "Abmeldung von der Mailingliste fehlgeschlagen",
+    "Go to latest message" : "Zur ältesten Nachricht springen",
+    "Go to newest message" : "Zur neuesten Nachricht springen",
+    "Thread Summary" : "Zusammenfassung der Unterhaltung",
+    "{name} Assistant" : "{name} Assistent",
+    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Deaktiviere die Aufbewahrung im Papierkorb, indem du das Feld leer lässt oder auf 0 setzt. Es werden nur Mails verarbeitet, die nach der Aktivierung der Aufbewahrung im Papierkorb gelöscht wurden.",
     "Remove" : "Entfernen",
     "No senders are trusted at the moment." : "Derzeit sind keine Absender vertrauenswürdig.",
     "Could not remove trusted sender {sender}" : "Vertrauenswürdiger Absender konnte nicht entfernt werden {sender}",
@@ -453,6 +506,8 @@ OC.L10N.register(
     "Provision all accounts" : "Alle Konten bereitstellen",
     "Allow additional mail accounts" : "Zusätzliche E-Mail-Konten zulassen",
     "Allow additional Mail accounts from User Settings" : "Zusätzliche E-Mail-Konten in den Benutzereinstellungen zulassen",
+    "Enable thread summary" : "Zusammenfassung der Unterhaltung aktivieren",
+    "Enable thread summaries" : "Zusammenfassungen der Unterhaltungen aktivieren",
     "Anti Spam Service" : "Anti-Spam-Dienst",
     "You can set up an anti spam service email address here." : "Hier kannst du eine E-Mail-Adresse für einen Anti-Spam-Dienst einrichten.",
     "Any email that is marked as spam will be sent to the anti spam service." : "Jede als Spam markierte E-Mail wird an den Anti-Spam-Dienst weitergeleitet.",
@@ -507,6 +562,8 @@ OC.L10N.register(
     "Host" : "Host",
     "Port" : "Port",
     "SMTP" : "SMTP",
+    "Master password" : "Masterpasswort",
+    "Use master password" : "Masterpasswort benutzen",
     "Sieve" : "Sieve",
     "Enable sieve integration" : "Sieve-Einbindung aktivieren",
     "LDAP aliases integration" : "LDAP-Alias-Integration",
@@ -550,6 +607,8 @@ OC.L10N.register(
     "You can close this window" : "Du kannst dieses Fenster schließen.",
     "Connect your mail account" : "Verbinde dein E-Mail-Konto",
     "To add a mail account, please contact your administrator." : "Kontaktiere bitte deinen Administrator, um ein E-Mail-Konto hinzuzufügen.",
+    "Tomorrow – {timeLocale}" : "Morgen – {timeLocale}",
+    "Later today – {timeLocale}" : "Später am Tag – {timeLocale}",
     "Itinerary for {type} is not supported yet" : "Reiseroute für {type} wird noch nicht unterstützt",
     "All" : "Alle",
     "Drafts" : "Entwürfe",
@@ -570,6 +629,7 @@ OC.L10N.register(
     "Discard unsaved changes" : "Nicht gespeicherte Änderungen verwerfen",
     "Keep editing message" : "Nachricht weiter bearbeiten",
     "Attachments were not copied. Please add them manually." : "Anhänge konnten nicht kopiert werden. Bitte manuell hinzufügen.",
+    "Could not create snooze mailbox" : "Das Zurückstellen-Postfach konnte nicht erstellt werden",
     "Message sent" : "Nachricht wurde gesendet",
     "Could not send message" : "Nachricht konnte nicht gelöscht werden",
     "Could not load {tag}{name}{endtag}" : "Konnte {tag}{name}{endtag} nicht laden",
