@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Ενσωματωμένο μήνυμα %s",
     "Important mail" : "Σημαντική αλληλογραφία",
+    "No message found yet" : "Δε βρέθηκε μήνυμα ακόμη.",
+    "Set up an account" : "Ρυθμίστε ένα λογαριασμό",
     "Unread mail" : "Μη αναγνωσμένη αλληλογραφία",
     "Important" : "Σημαντικό ",
     "Work" : "Εργασία",
@@ -71,6 +73,8 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Χρησιμοποιήστε Gravatar και favicon avatars",
     "Register as application for mail links" : "Εγγραφή ως εφαρμογή για συνδέσμους αλληλογραφίας",
     "Show keyboard shortcuts" : "Εμφάνιση συντομεύσεων πληκτρολογίου",
+    "Newest" : "Νεότερο",
+    "Oldest" : "Παλαιότερο",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Να επιτρέπεται στην εφαρμογή να συλλέγει δεδομένα σχετικά με την δραστηριότητά σας. Με βάση αυτά τα δεδομένα, η εφαρμογή θα προσαρμοστεί στις προτιμήσεις σας. Τα δεδομένα θα αποθηκευτούν μόνο τοπικά.",
     "Put my text to the bottom of a reply instead of on top of it." : "Το κείμενό μου στο κάτω μέρος μιας απάντησης αντί στο επάνω μέρος της.",
     "Automatically classify importance of new email" : "Αυτόματη ταξινόμηση σπουδαιότητας νέων email",
@@ -112,8 +116,6 @@ OC.L10N.register(
     "_{count} attachment_::_{count} attachments_" : ["{count} συνημμένo","{count} συνημμένα"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Το συνημμένο υπερβαίνει το επιτρεπόμενο μέγεθος συνημμένων {size}. Παρακαλούμε διαμοιράστε το αρχείο μέσω συνδέσμου.","Τα συνημμένα υπερβαίνουν το επιτρεπόμενο μέγεθος συνημμένων {size}. Παρακαλούμε διαμοιράστε τα αρχεία μέσω συνδέσμου."],
     "Confirm" : "Επιβεβαίωση",
-    "No message found yet" : "Δε βρέθηκε μήνυμα ακόμη.",
-    "Set up an account" : "Ρυθμίστε ένα λογαριασμό",
     "Plain text" : "Απλό κείμενο",
     "Rich text" : "Εμπλουτισμένο κείμενο",
     "No messages in this mailbox" : "Δεν υπάρχουν μηνύματα σε αυτό το γραμματοκιβώτιο.",
@@ -197,7 +199,6 @@ OC.L10N.register(
     "Forward message as attachment" : "Προώθηση μηνύματος ως συνημμένο",
     "View source" : "Προβολή πηγής",
     "Download thread data for debugging" : "Λήψη δεδομένων νήματος ακολουθίας για εντοπισμό σφαλμάτων",
-    "Message source" : "Πηγή μηνύματος",
     "Message body" : "Σώμα μηνύματος",
     "Import into calendar" : "Εισαγωγή στο ημερολόγιο",
     "Download attachment" : "Λήψη συνημμένου",
@@ -278,6 +279,7 @@ OC.L10N.register(
     "Contact name …" : "Όνομα επαφής ...",
     "Add" : "Προσθήκη",
     "Close" : "Κλείσιμο",
+    "Body" : "Σώμα",
     "Tags" : "Ετικέτες",
     "Select tags" : "Επιλέξτε ετικέτες",
     "Clear" : "Εκκαθάριση",
@@ -290,14 +292,14 @@ OC.L10N.register(
     "Sieve User" : "Χρήστης Sieve",
     "Signature …" : "Υπογραφή...",
     "Save signature" : "Αποθήκευση υπογραφής",
-    "Add default tags" : "Προσθήκη προεπιλεγμένων ετικετών",
-    "Rename tag" : "Μετονομασία ετικέτας",
+    "Delete tag" : "Διαγραφή ετικέτας",
     "Saving new tag name …" : "Αποθήκευση νέου ονόματος ετικέτας…",
+    "An error occurred, unable to rename the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία της ετικέτας.",
+    "Add default tags" : "Προσθήκη προεπιλεγμένων ετικετών",
     "Add tag" : "Προσθήκη ετικέτας",
     "Saving tag …" : "Αποθήκευση ετικέτας…",
     "Tag already exists" : "Υπάρχει ήδη η ετικέτα",
     "An error occurred, unable to create the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η δημιουργία της ετικέτας.",
-    "An error occurred, unable to rename the tag." : "Παρουσιάστηκε σφάλμα, δεν ήταν δυνατή η μετονομασία της ετικέτας.",
     "Not found" : "Δε βρέθηκε",
     "Could not load your message thread" : "Δεν ήταν δυνατή η φόρτωση του μηνύματός σας",
     "Unsubscribe" : "Κατάργηση εγγραφής",
@@ -305,6 +307,7 @@ OC.L10N.register(
     "Mark as unread" : "επισήμανση ως μή-αναγνωσμένο",
     "Mark as read" : "Σήμανση ως αναγνωσμένο",
     "Delete message" : "Διαγραφή μηνύματος",
+    "Message source" : "Πηγή μηνύματος",
     "Remove" : "Αφαίρεση",
     "No senders are trusted at the moment." : "Κανένας αποστολέας δεν είναι αξιόπιστος αυτή τη στιγμή.",
     "Could not remove trusted sender {sender}" : "Δεν ήταν δυνατή η κατάργηση του αξιόπιστου αποστολέα {sender}",
