@@ -45,6 +45,7 @@ OC.L10N.register(
     "Add mail account" : "Aldoni retpoŝtan konton",
     "Use Gravatar and favicon avatars" : "Uzi servon „Gravatar“ kaj avatarojn en retpaĝsimbolo",
     "Register as application for mail links" : "Registriĝi kiel programeto por retpoŝtligiloj",
+    "Show keyboard shortcuts" : "Montri klavarajn ŝparvojojn",
     "From" : "De",
     "Select account" : "Elekti konton",
     "To" : "Al",
@@ -127,6 +128,7 @@ OC.L10N.register(
     "Custom" : "Propra",
     "Signature …" : "Subskribo …",
     "Save signature" : "Konservi subskribon",
+    "Delete tag" : "Forigi etikedon",
     "Tag already exists" : "La etikedo jam ekzistas",
     "Not found" : "Ne trovita",
     "Remove" : "Forigi",
