@@ -24,7 +24,9 @@ OC.L10N.register(
     "Save" : "Guardar",
     "Connect" : "Conectar",
     "Password required" : "Se requiere contraseña",
+    "Aliases" : "Aliases",
     "Signature" : "Firma",
+    "Go back" : "Regresar",
     "Change name" : "Cambiar nombre",
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
@@ -35,12 +37,14 @@ OC.L10N.register(
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Confirm" : "Confirmar",
     "Unfavorite" : "Quitar favorito",
     "Favorite" : "Marcar como favorito",
     "Read" : "Leer",
     "Select" : "Seleccionar",
     "Edit tags" : "Editar etiquetas",
     "More actions" : "Más acciones",
+    "Back" : "Atrás",
     "Forward" : "Adelante",
     "All day" : "Todo el día",
     "Create" : "Crear",
@@ -65,13 +69,14 @@ OC.L10N.register(
     "Edit name" : "Editar nombre",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
-    "Go back" : "Regresar",
+    "Refresh" : "Actualizar",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
     "Message" : "Mensaje",
     "Delete" : "Borrar",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
+    "Close" : "Cerrar",
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
     "Clear" : "Limpiar",
@@ -80,8 +85,6 @@ OC.L10N.register(
     "Disabled" : "Deshabilitado",
     "Enabled" : "Habilitado",
     "Custom" : "Personalizado",
-    "Set" : "Establecer",
-    "Unset" : "Desestablecer",
     "Add tag" : "Agregar etiqueta",
     "Tag already exists" : "La etiqueta ya existe",
     "Remove" : "Eliminar",
@@ -94,7 +97,6 @@ OC.L10N.register(
     "Port" : "Puerto",
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
-    "Back" : "Atrás",
     "Submit" : "Enviar",
     "Keyboard shortcut" : "Atajo del teclado",
     "Keyboard shortcuts" : "Atajos del teclado",
@@ -105,7 +107,6 @@ OC.L10N.register(
     "Toggle star" : "Alternar favoritos",
     "Toggle unread" : "Alternar no leídos",
     "Archive" : "Archivar",
-    "Refresh" : "Actualizar",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
