@@ -23,7 +23,10 @@ OC.L10N.register(
     "Connecting" : "Conectando",
     "Save" : "Guardar",
     "Connect" : "Conectar",
+    "Password required" : "Se requiere contraseña",
+    "Aliases" : "Aliases",
     "Signature" : "Firma",
+    "Go back" : "Regresar",
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
@@ -31,19 +34,16 @@ OC.L10N.register(
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
-    "Sending …" : "Enviando ...",
-    "Go back" : "Regresar",
-    "Retry" : "Reintentar",
-    "Message sent!" : "¡Mensaje enviado!",
     "Send" : "Enviar",
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
+    "Confirm" : "Confirmar",
     "Unfavorite" : "Quitar favorito",
     "Favorite" : "Hacer favorito",
     "Read" : "Leer",
     "Select" : "Seleccionar",
     "Edit tags" : "Editar etiquetas",
-    "Move" : "Mover",
     "More actions" : "Más acciones",
+    "Back" : "Atrás",
     "Forward" : "Adelante",
     "All day" : "Todo el día",
     "Create" : "Crear",
@@ -60,17 +60,23 @@ OC.L10N.register(
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
+    "Move" : "Mover",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
     "Remove account" : "Eliminar cuenta",
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
+    "Refresh" : "Actualizar",
+    "Retry" : "Reintentar",
+    "Sending …" : "Enviando ...",
     "Message" : "Mensaje",
     "Delete" : "Borrar",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
+    "Close" : "Cerrar",
     "Tags" : "Etiquetas",
+    "Select tags" : "Selecciona las etiquetas",
     "Clear" : "Limpiar",
     "Search" : "Buscar",
     "Date" : "Fecha",
@@ -80,10 +86,15 @@ OC.L10N.register(
     "Add tag" : "Agregar etiqueta",
     "Remove" : "Eliminar",
     "Reset" : "Restablecer",
+    "Client ID" : "ID del cliente",
+    "Client secret" : "Secreto del cliente",
     "General" : "General",
     "User" : "Usuario",
     "Host" : "Servidor",
     "Port" : "Puerto",
+    "Valid until" : "Válido hasta",
+    "Certificate" : "Certificado",
+    "Submit" : "Enviar",
     "Keyboard shortcut" : "Atajo del teclado",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Speed up your Mail experience with these quick shortcuts." : "Haz más rápida tu experiencia de Correo con estos atajos rápidos. ",
@@ -92,10 +103,9 @@ OC.L10N.register(
     "Older message" : "Mensaje más antiguo",
     "Toggle star" : "Alternar favoritos",
     "Toggle unread" : "Alternar no leídos",
-    "Refresh" : "Actualizar",
+    "Archive" : "Archivar",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
-    "Archive" : "Archivar",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
     "All inboxes" : "Todos los buzones de entrada",
