@@ -34,12 +34,14 @@ OC.L10N.register(
     "Enter a date" : "Sisesta kuupäev",
     "Send" : "Saada",
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
+    "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
     "Confirm" : "Kinnita",
     "Favorite" : "Lemmik",
     "Read" : "Lugemine",
     "Select" : "Vali",
     "Edit tags" : "Muuda silte",
     "Back" : "Tagasi",
+    "Create event" : "Lisa sündmus",
     "Forward" : "Edasi",
     "All day" : "Kogu päev",
     "Create" : "Loo",
