@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Txertatutako mezua %s",
     "Important mail" : "Posta garrantzitsua",
+    "No message found yet" : "Ez da mezurik aurkitu oraindik.",
+    "Set up an account" : "Konfiguratu kontu bat",
     "Unread mail" : "Irakurri gabeko posta",
     "Important" : "Garrantzitsua",
     "Work" : "Lana",
@@ -10,6 +12,8 @@ OC.L10N.register(
     "To Do" : "Egiteke",
     "Later" : "Beranduago",
     "Mail" : "Posta",
+    "You are reaching your mailbox quota limit for {account_email}" : "{account_email} konturako postontziaren kuota-mugara heltzen ari zara",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Zure postontziaren biltegiaren {percentage} erabiltzen ari zara une honetan. Mesedez, egin ezazu lekua behar ez dituzun postak ezabatuz.",
     "Mails" : "Posta",
     "💌 A mail app for Nextcloud" : "💌 Posta elektroniko zerbitzu bat Nextcloudekin",
     "Your session has expired. The page will be reloaded." : "Zure saioa iraungi da. Orria berriro kargatuko da.",
@@ -17,6 +21,8 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Bidalitako mezuak hemen gordetzen dira:",
     "Deleted messages are moved in:" : "Ezabatutako mezuak hona mugitzen dira:",
     "Archived messages are moved in:" : "Artxibatutako mezuak hona mugitzen dira:",
+    "Snoozed messages are moved in:" : "Beste aldi baterako utzitako mezuak hona mugitzen dira:",
+    "Junk messages are saved in:" : "Zabor mezuak hemen gordetzen dira:",
     "Auto" : "Auto",
     "Name" : "Izena",
     "Mail address" : "Helbide elektronikoa",
@@ -51,7 +57,9 @@ OC.L10N.register(
     "Password required" : "Pasahitza beharrezkoa da",
     "Testing authentication" : "Autentifikazioa probatzen",
     "Awaiting user consent" : "Erabiltzailearen onarpenaren zain",
+    "Account created. Please follow the pop-up instructions to link your Google account" : "Kontua sortu da. Mesedez, jarraitu popup-aren jarraibideak zure Google kontua estekatzeko",
     "Loading account" : "Kontua kargatzen",
+    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Kontua eguneratu da. Mesedez, jarraitu popup-aren jarraibideak zure Google kontua berriro konektatzeko",
     "Account updated" : "Kontua eguneratu da",
     "IMAP server is not reachable" : "IMAP zerbitzaria ezin da atzitu",
     "SMTP server is not reachable" : "SMTP zerbitzaria ezin da atzitu",
@@ -69,6 +77,8 @@ OC.L10N.register(
     "Writing mode" : "Editatzeko aukera gaituta",
     "Preferred writing mode for new messages and replies." : "Hobetsitako idazteko modua, mezu berri eta erantzunak idazteko.",
     "Default folders" : "Lehenetsitako karpetak",
+    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Zirriborro, bidalitako, ezabatutako, artxibatutako eta zabor mezuentzako erabilitako karpeta.",
+    "Automatic trash deletion" : "Zaborraren ezabatze automatikoa",
     "Autoresponder" : "Autoerantzulea",
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Sarrerako mezuei erantzun automatikoa. Norbaitek hainbat mezu bidaltzen badizu, erantzun automatizatu hau gehienez 4 egunean behin bidaliko da.",
     "Please connect to a sieve server first." : "Konektatu sieve zerbitzari batera lehenik mesedez.",
@@ -91,6 +101,8 @@ OC.L10N.register(
     "Register as application for mail links" : "Erregistratu posta-estekentzako aplikazio bezala",
     "Show keyboard shortcuts" : "Erakutsi teklatuaren lasterbideak",
     "Manage S/MIME certificates" : "Kudeatu S/MIME ziurtagiriak",
+    "Newest" : "Berrienak",
+    "Oldest" : "Zaharrenak",
     "Looking for a way to encrypt your emails?" : "Zure mezu elektronikoak enkriptatzeko modu bat bilatzen ari zara?",
     "Install Mailvelope browser extension here" : "Instalatu Mailvelope arakatzailearen luzapena hemen",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Baimena eman aplikazioari zure interakzioei buruzko datuak biltzeko. Datu horietan oinarrituta, aplikazioa zure hobespenetara egokituko da. Datuak lokalki bakarrik gordeko dira.",
@@ -158,8 +170,6 @@ OC.L10N.register(
     "Close composer" : "Itxi egilea",
     "Untitled message" : "Izenik gabeko mezua",
     "Confirm" : "Berretsi",
-    "No message found yet" : "Ez da mezurik aurkitu oraindik.",
-    "Set up an account" : "Konfiguratu kontu bat",
     "Plain text" : "Testu arrunta",
     "Rich text" : "Testu aberastua",
     "No messages in this mailbox" : "Mezurik ez postontzi honetan",
@@ -177,6 +187,7 @@ OC.L10N.register(
     "Unselect" : "Desautatu",
     "Select" : "Hautatu",
     "Edit tags" : "Editatu etiketak",
+    "Snooze" : "Beste aldi baterako utzi",
     "Move thread" : "Mugitu haria",
     "Archive thread" : "Artxibatu haria",
     "Delete thread" : "Ezabatu haria",
@@ -253,7 +264,6 @@ OC.L10N.register(
     "Forward message as attachment" : "Birbidali mezua eranskin gisa",
     "View source" : "Ikusi iturburua",
     "Download thread data for debugging" : "Deskargatu hariaren datuak arazteko",
-    "Message source" : "Mezuaren iturburua",
     "Message body" : "Mezuaren gorputza",
     "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Abisua: mezu honen S/MIME sinadura egiaztatu gabe dago. Baliteke igorleak norbaiten nortasuna ordezkatzea!",
     "Import into calendar" : "Inportatu egutegira",
@@ -287,6 +297,7 @@ OC.L10N.register(
     "Quota" : "Kuota",
     "Show only subscribed mailboxes" : "Erakutsi harpidetutako postontziak soilik",
     "Add mailbox" : "Gehitu postontzia",
+    "Mailbox name" : "Postontziaren izena",
     "Saving" : "Gordetzen",
     "Move up" : "Eraman gora",
     "Move down" : "Eraman behera",
@@ -323,7 +334,7 @@ OC.L10N.register(
     "Refresh" : "Freskatu",
     "Error sending your message" : "Errorea zure mezua bidaltzerakoan",
     "Retry" : "Saiatu berriro",
-    "Uploading attachments …" : "Fitxategi erantsiak kargatzen...",
+    "Uploading attachments …" : "Fitxategi erantsiak igotzen...",
     "Sending …" : "Bidaltzen...",
     "Warning sending your message" : "Abisua zure mezua bidaltzerakoan",
     "Send anyway" : "Bidali nolanahi ere",
@@ -333,10 +344,14 @@ OC.L10N.register(
     "Message saved" : "Mezua gordeta",
     "Failed to save message" : "Mezua gordetzeak huts egin du",
     "Failed to save draft" : "Zirriborroa gordetzeak huts egin du",
+    "attachment" : "eranskina",
+    "attached" : "erantsita",
     "No sent mailbox configured. Please pick one in the account settings." : "Ez dago bidalitakoen postontzirik konfiguratuta. Aukeratu baten bat kontuaren ezarpenetan, mesedez.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "To eta / edo Cc-n hartzaile askori bidaltzen saiatzen ari zara. Hartzaileen helbideak ezkutatzeko Bcc erabili dezakezu.",
+    "You mentioned an attachment. Did you forget to add it?" : "Eranskin bat aipatu duzu. Gehitzea ahaztu al zaizu?",
     "Message discarded" : "Mezua bertan behera utzi da",
     "Could not discard message" : "Ezin izan da mezua baztertu",
+    "Welcome to {cloudName} Mail" : "Ongi etorri {cloudName} postara",
     "Autoresponder off" : "Autoerantzulea itzalita",
     "Autoresponder on" : "Autoerantzulea piztuta",
     "First day" : "Lehen eguna",
@@ -361,7 +376,7 @@ OC.L10N.register(
     "Search in mailbox" : "Bilatu postontzian",
     "Close" : "Itxi",
     "Search parameters" : "Bilaketa parametroak",
-    "Search term" : "Bilaketa terminoa",
+    "Body" : "Gorputza",
     "Pick a start date" : "Aukeratu hasiera-data",
     "Pick an end date" : "Aukeratu amaiera-data",
     "Select senders" : "Hautatu bidaltzaileak",
@@ -393,23 +408,25 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Zure sinadurak 2MB baino gehiago ditu. Honek editorearen errendimendua gutxitu dezake.",
     "Save signature" : "Gorde sinadura",
     "Place signature above quoted text" : "Jarri sinadura aipatutako testuaren gainean",
-    "Add default tags" : "Gehitu etiketa lehenetsiak",
-    "Rename tag" : "Berrizendatu etiketa",
+    "Edit name or color" : "Editatu izena edo kolorea",
+    "Delete tag" : "Ezabatu etiketa",
     "Saving new tag name …" : "Etiketa-izen berria gordetzen ...",
     "Set tag" : "Ezarri etiketa",
     "Unset tag" : "Ezarri gabeko etiketa",
+    "An error occurred, unable to rename the tag." : "Errore bat gertatu da, ezin izan zaio etiketa aldatu.",
+    "Add default tags" : "Gehitu etiketa lehenetsiak",
     "Add tag" : "Gehitu etiketa",
     "Saving tag …" : "Etiketa gordetzen",
     "Tag name is a hidden system tag" : "Etiketaren izena ezkutatutako sistema-etiketa da",
     "Tag already exists" : "Etiketa dagoeneko existitzen da",
     "An error occurred, unable to create the tag." : "Errore bat gertatu da, ezin da etiketa sortu.",
-    "An error occurred, unable to rename the tag." : "Errore bat gertatu da, ezin izan zaio etiketa aldatu.",
     "Select calendar" : "Hautatu egutegia",
     "No calendars with task list support" : "Ez dago eginkizun-zerrendarik onartzen duen egutegirik",
     "Task created" : "Eginkizuna sortuta",
     "Could not create task" : "Ezin izan da eginkizuna sortu",
     "Loading thread" : "Haria kargatzen",
     "Not found" : "Ez da aurkitu",
+    "Summarizing thread failed." : "Haria laburbiltzeak huts egin du.",
     "Could not load your message thread" : "Ezin izan da zure mezuen haria kargatu",
     "The thread doesn't exist or has been deleted" : "Haria ez da existitzen edo ezabatu egin da",
     "Unsubscribe" : "Harpidetza kendu",
@@ -419,7 +436,9 @@ OC.L10N.register(
     "Mark as read" : "Markatu irakurritako gisa",
     "Archive message" : "Artxibatu mezua",
     "Delete message" : "Mezua ezabatzen",
+    "Message source" : "Mezuaren iturburua",
     "Unsubscribe via link" : "Harpidetza kendu esteka bidez",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "Harpidetza kentzeak {sender} posta-zerrendako mezu guztiak geldituko ditu",
     "Send unsubscribe email" : "Bidali harpidetza kentzeko mezu elektronikoa",
     "Unsubscribe via email" : "Harpidetza kendu mezu elektroniko bidez",
     "Encrypted & verified " : "Enkriptatuta eta egiaztatua",
@@ -430,6 +449,10 @@ OC.L10N.register(
     "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Mezu honek egiaztatu gabeko S/MIME sinadura digital bat dauka. Baliteke mezua bidali zenetik aldatu izana edo sinatzailearen ziurtagiria fidagarria ez izatea.",
     "Unsubscribe request sent" : "Harpidetza kentze eskaera bidalita",
     "Could not unsubscribe from mailing list" : "Ezin izan da posta-zerrendako harpidetza kendu",
+    "Go to latest message" : "Joan azken mezura",
+    "Go to newest message" : "Joan mezu berrienera",
+    "Thread Summary" : "Hariaren laburpena",
+    "{name} Assistant" : "{name} laguntzailea",
     "Remove" : "Kendu",
     "No senders are trusted at the moment." : "Une honetan ez da igorle fidagarririk.",
     "Could not remove trusted sender {sender}" : "Ezin izan da {sender} igorle fidagarria kendu",
@@ -462,6 +485,8 @@ OC.L10N.register(
     "Provision all accounts" : "Hornitu kontu guztiak",
     "Allow additional mail accounts" : "Onartu e-mail kontu gehigarriak",
     "Allow additional Mail accounts from User Settings" : "Onartu posta kontu gehigarriak erabiltzaile ezarpenetatik",
+    "Enable thread summary" : "Gaitu harien laburbiltzea",
+    "Enable thread summaries" : "Gaitu harien laburbiltzea",
     "Anti Spam Service" : "Anti spam zerbitzua",
     "You can set up an anti spam service email address here." : "Hemen spamaren aurkako zerbitzuaren helbide elektronikoa konfigura dezakezu.",
     "Any email that is marked as spam will be sent to the anti spam service." : "Spam gisa markatutako edozein mezu elektroniko spamaren aurkako zerbitzura bidaliko da.",
