@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Upotettu viesti %s",
     "Important mail" : "Tärkeä sähköposti",
+    "No message found yet" : "Yhtäkään viestiä ei ole vielä löytynyt",
+    "Set up an account" : "Määritä tili",
     "Unread mail" : "Lukematon sähköposti",
     "Important" : "Tärkeä",
     "Work" : "Työ",
@@ -84,6 +86,8 @@ OC.L10N.register(
     "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
     "Show keyboard shortcuts" : "Näytä pikanäppäimet",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
+    "Newest" : "Uusimmat",
+    "Oldest" : "Vanhimmat",
     "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
     "Install Mailvelope browser extension here" : "Asenna Mailvelope-selainlaajennus täältä",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
@@ -146,8 +150,6 @@ OC.L10N.register(
     "Close composer" : "Sulje lähetysikkuna",
     "Untitled message" : "Nimetön viesti",
     "Confirm" : "Vahvista",
-    "No message found yet" : "Yhtäkään viestiä ei ole vielä löytynyt",
-    "Set up an account" : "Määritä tili",
     "Plain text" : "Raakateksti",
     "Rich text" : "Rikas teksti",
     "No messages in this mailbox" : "Ei viestejä tässä postilaatikossa",
@@ -228,7 +230,6 @@ OC.L10N.register(
     "Forward message as attachment" : "Välitä viesti liitteenä",
     "View source" : "Näytä lähde",
     "Download thread data for debugging" : "Lataa ketjun data vianjäljitystä varten",
-    "Message source" : "Viestin lähde",
     "Message body" : "Viestin runko",
     "Import into calendar" : "Tuo kalenteriin",
     "Download attachment" : "Lataa liite",
@@ -325,6 +326,7 @@ OC.L10N.register(
     "Copied email address to clipboard" : "Sähköpostiosoite kopioitu leikepöydälle",
     "Could not copy email address to clipboard" : "Sähköpostiosoitetta ei voitu kopioida leikepöydälle",
     "Close" : "Sulje",
+    "Body" : "Sisältö",
     "Pick a start date" : "Valitse aloituspäivä",
     "Pick an end date" : "Valitse päättymispäivä",
     "Tags" : "Tunnisteet",
@@ -349,15 +351,15 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
-    "Add default tags" : "Lisää oletustunnisteet",
-    "Rename tag" : "Uudelleennimeä tunniste",
+    "Delete tag" : "Poista tunniste",
     "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
+    "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
+    "Add default tags" : "Lisää oletustunnisteet",
     "Add tag" : "Lisää tunniste",
     "Saving tag …" : "Tallennetaan tunnistetta…",
     "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
     "Tag already exists" : "Tunniste on jo olemassa",
     "An error occurred, unable to create the tag." : "Tapahtui virhe, tunnistetta ei voitu luoda.",
-    "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
     "Select calendar" : "Valitse kalenteri",
     "Task created" : "Tehtävä luotu",
     "Loading thread" : "Ladataan ketjua",
@@ -370,6 +372,7 @@ OC.L10N.register(
     "Mark as read" : "Merkitse luetuksi",
     "Archive message" : "Arkistoi viesti",
     "Delete message" : "Poista viesti",
+    "Message source" : "Viestin lähde",
     "Encrypted & verified " : "Salattu ja vahvistettu",
     "Signature verified" : "Allekirjoitus vahvistettu",
     "Signature unverified " : "Allekirjoitus vahvistamatta",
