@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Messaggio incorporato %s",
     "Important mail" : "Posta importante",
+    "No message found yet" : "Ancora nessun messaggio trovato",
+    "Set up an account" : "Configura un account",
     "Unread mail" : "Messaggio non letto",
     "Important" : "Importante",
     "Work" : "Lavoro",
@@ -50,6 +52,7 @@ OC.L10N.register(
     "Writing mode" : "Modalità di scrittura",
     "Preferred writing mode for new messages and replies." : "Modalità di scrittura preferita per nuovi messaggi e risposte.",
     "Default folders" : "Cartelle predefinite",
+    "Autoresponder" : "Risponditore automatico",
     "Sieve filter rules" : "Regole di filtro Sieve",
     "Trusted senders" : "Mittenti affidabili",
     "Mail server" : "Server di posta",
@@ -67,6 +70,8 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
     "Register as application for mail links" : "Registra come applicazione per i collegamenti di posta",
     "Show keyboard shortcuts" : "Mostra scorciatoie da tastiera",
+    "Newest" : "Più recente",
+    "Oldest" : "Il più vecchio",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Consenti all'applicazione di raccogliere dati sulle tue interazioni. Sulla base di questi dati, l'applicazione si adatterà alle tue preferenze. I dati saranno archiviati solo localmente.",
     "Put my text to the bottom of a reply instead of on top of it." : "Inserisci il mio testo in fondo alla risposta invece che sopra.",
     "Automatically classify importance of new email" : "Classifica automaticamente l'importanza delle email nuove",
@@ -106,8 +111,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Scegli un file da condividere come un collegamento",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece il file tramite collegamento.","Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece i file tramite collegamento.","Gli allegati superano le dimensioni consentite per gli allegati di {size}. Condividere invece i file tramite collegamento."],
     "Confirm" : "Conferma",
-    "No message found yet" : "Ancora nessun messaggio trovato",
-    "Set up an account" : "Configura un account",
     "Plain text" : "Testo semplice",
     "Rich text" : "Testo formattato",
     "No messages in this mailbox" : "Nessun messaggio in questa casella di posta",
@@ -172,7 +175,6 @@ OC.L10N.register(
     "Move message" : "Sposta messaggio",
     "View source" : "Visualizza sorgente",
     "Download thread data for debugging" : "Scarica i dati del conversazione per il debug",
-    "Message source" : "Sorgente del messaggio",
     "Message body" : "Corpo del messaggio",
     "Import into calendar" : "Importa nel calendario",
     "Download attachment" : "Scarica allegato",
@@ -250,6 +252,7 @@ OC.L10N.register(
     "Contact name …" : "Nome contatto …",
     "Add" : "Aggiungi",
     "Close" : "Chiudi",
+    "Body" : "Corpo",
     "Tags" : "Etichette",
     "Select tags" : "Seleziona etichette",
     "Clear" : "Pulisci",
@@ -270,20 +273,21 @@ OC.L10N.register(
     "Signature …" : "Firma...",
     "Save signature" : "Salva firma",
     "Place signature above quoted text" : "Posiziona la firma sopra il testo citato",
-    "Add default tags" : "Aggiungi etichette predefiniti",
-    "Rename tag" : "Rinomina l'etichetta",
+    "Delete tag" : "Elimina etichetta",
     "Saving new tag name …" : "Salvataggio nuovo nome della etichetta...",
+    "An error occurred, unable to rename the tag." : "Si è verificato un errore, impossibile rinominare l'etichetta.",
+    "Add default tags" : "Aggiungi etichette predefiniti",
     "Add tag" : "Aggiungi etichetta",
     "Saving tag …" : "Salvataggio etichetta …",
     "Tag already exists" : "L'etichetta esiste già",
     "An error occurred, unable to create the tag." : "Si è verificato un errore, impossibile creare l'etichetta.",
-    "An error occurred, unable to rename the tag." : "Si è verificato un errore, impossibile rinominare l'etichetta.",
     "Not found" : "Non trovato",
     "Could not load your message thread" : "Impossibile caricare la tua discussione",
     "Unsubscribe" : "Rimuovi sottoscrizione",
     "Mark as unread" : "Segna come non letto",
     "Mark as read" : "Segna come letto",
     "Delete message" : "Elimina messaggio",
+    "Message source" : "Sorgente del messaggio",
     "Remove" : "Rimuovi",
     "No senders are trusted at the moment." : "Nessun mittente è fidato al momento.",
     "Could not remove trusted sender {sender}" : "Impossibile rimuovere il mittente fidato {sender}",
@@ -338,6 +342,7 @@ OC.L10N.register(
     "Error deleting anti spam reporting email" : "Errore durante l'eliminazione dell'e-mail di segnalazione Anti-Spam",
     "Client ID" : "ID client",
     "Client secret" : "Segreto del client",
+    "Unlink" : "Scollegare",
     "Domain Match: {provisioningDomain}" : "Corrispondenza di dominio: {provisioningDomain}",
     "Email: {email}" : "Email: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} su {host}:{port} (cifratura {ssl})",
