@@ -2,6 +2,8 @@ OC.L10N.register(
     "mail",
     {
     "Important mail" : "重要なメール",
+    "No message found yet" : "メッセージはまだありません",
+    "Set up an account" : "アカウントを設定",
     "Unread mail" : "未読メール",
     "Important" : "重要",
     "Work" : "仕事",
@@ -35,6 +37,7 @@ OC.L10N.register(
     "SMTP User" : "SMTPユーザー",
     "SMTP Password" : "SMTPパスワード",
     "Connecting" : "接続中",
+    "Sign in with Google" : "Googleでサインイン",
     "Save" : "保存",
     "Connect" : "接続",
     "Password required" : "パスワードが必要です",
@@ -88,8 +91,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "共有リンクにして送信するファイルを選択",
     "_{count} attachment_::_{count} attachments_" : ["{count} 個の添付ファイル"],
     "Confirm" : "承認",
-    "No message found yet" : "メッセージはまだありません",
-    "Set up an account" : "アカウントを設定",
     "Plain text" : "プレーンテキスト",
     "Rich text" : "リッチテキスト",
     "No messages in this mailbox" : "このメールボックスにメッセージはありません",
@@ -97,6 +98,7 @@ OC.L10N.register(
     "Draft: " : "下書き",
     "Unfavorite" : "お気に入りから外す",
     "Favorite" : "お気に入り",
+    "Unread" : "未読",
     "Read" : "読み込み",
     "Mark not spam" : "迷惑メールとしない",
     "Mark as spam" : "迷惑メールとする",
@@ -113,11 +115,14 @@ OC.L10N.register(
     "Could not delete message" : "メッセージを削除できませんでした",
     "Forward" : "転送",
     "Load more" : "さらに読み込む",
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["{number}をスパムとしてマーク"],
+    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["{number}件をスパムでないとマーク"],
     "Report this bug" : "不具合を報告",
     "All day" : "終日",
     "Create" : "作成",
     "Event created" : "イベントが作成しました",
     "Could not create event" : "イベントを作成できませんでした。",
+    "Save to" : "に保存",
     "Comment" : "コメント",
     "Accept" : "承諾",
     "Decline" : "拒否",
@@ -135,7 +140,6 @@ OC.L10N.register(
     "Reply to sender only" : "送信者のみに返信",
     "Move message" : "メッセージを移動",
     "View source" : "ソースを表示",
-    "Message source" : "メッセージソース",
     "Import into calendar" : "カレンダーにインポート",
     "Download attachment" : "添付ファイルをダウンロード",
     "Save to Files" : "ファイルに保存",
@@ -188,6 +192,7 @@ OC.L10N.register(
     "Retry" : "再試行",
     "Uploading attachments …" : "添付ファイルをアップロード",
     "Sending …" : "送信中 …",
+    "First day" : "初日",
     "Message" : "メッセージ",
     "Oh Snap!" : "おっと！",
     "Could not open outbox" : "送信トレイを開けませんでした",
@@ -200,6 +205,7 @@ OC.L10N.register(
     "Contact name …" : "連絡先の名前…",
     "Add" : "追加",
     "Close" : "閉じる",
+    "Body" : "本文",
     "Tags" : "タグ",
     "Select tags" : "タグを選択",
     "Clear" : "クリア",
@@ -213,17 +219,18 @@ OC.L10N.register(
     "Sieve User" : "Sieveユーザー",
     "Signature …" : "署名…",
     "Save signature" : "署名を保存",
-    "Rename tag" : "タグ名を変更",
+    "Delete tag" : "タグを削除",
+    "An error occurred, unable to rename the tag." : "エラー:タグの名前を変更できませんでした",
     "Add tag" : "タグを追加",
     "Tag already exists" : "タグはすでに存在します",
     "An error occurred, unable to create the tag." : "エラー:タグを作成できませんでした",
-    "An error occurred, unable to rename the tag." : "エラー:タグの名前を変更できませんでした",
     "Not found" : "見つかりませんでした",
     "Could not load your message thread" : "メッセージを読み込めませんでした",
     "Unsubscribe" : "購読解除",
     "Mark as unread" : "未読にする",
     "Mark as read" : "既読にする",
     "Delete message" : "メッセージを削除",
+    "Message source" : "メッセージソース",
     "This message was encrypted by the sender before it was sent." : "このメッセージは送信前に送信者よって暗号化されました。",
     "Remove" : "削除",
     "domain" : "ドメイン",
