@@ -13,6 +13,7 @@ OC.L10N.register(
     "Confirm" : "Serggeg",
     "Favorite" : "Menyif",
     "Select" : "Fren",
+    "Back" : "Retour",
     "Forward" : "Avancer",
     "Create" : "Snulfu-d",
     "Comment" : "Commentaire",
@@ -20,6 +21,8 @@ OC.L10N.register(
     "Other" : "Wayeḍ",
     "Reply" : "Err",
     "Move" : "Senkez",
+    "Remove account" : "Kkes amiḍan",
+    "Loading …" : "Asali ...",
     "Refresh" : "Sismeḍ",
     "Retry" : "Ɛreḍ tikkelt-nniḍen",
     "Message" : "Izen",
@@ -36,7 +39,6 @@ OC.L10N.register(
     "Remove" : "Kkes",
     "General" : "Amatu",
     "User" : "Aseqdac",
-    "Back" : "Retour",
     "All" : "Akk",
     "Favorites" : "Imenyafen",
     "Inbox" : "Tanaka",
