@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Вметната порака %s",
     "Important mail" : "Важни пораки",
+    "No message found yet" : "Не се пронајдени пораки",
+    "Set up an account" : "Постави сметка",
     "Unread mail" : "Непрочитани пораки",
     "Important" : "Важно",
     "Work" : "Работа",
@@ -10,6 +12,8 @@ OC.L10N.register(
     "To Do" : "За правење",
     "Later" : "Покасно",
     "Mail" : "Електронска пошта",
+    "You are reaching your mailbox quota limit for {account_email}" : "Го достигнувате лимитот на квотата на вашето поштенско сандаче за {account_email}",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Во моментов користите {percentage} од складиштето на вашето поштенско сандаче. Направете простор со бришење на непотребните е-пораки.",
     "Mails" : "Е-пошта пораки",
     "💌 A mail app for Nextcloud" : "💌 Апликација за електронска пошта за Nextcloud",
     "Your session has expired. The page will be reloaded." : "Сесијата истече. Страната ќе биде повторно вчитана.",
@@ -50,6 +54,7 @@ OC.L10N.register(
     "Configuration discovery failed. Please use the manual settings" : "Неуспешна детекција на конфигурација. Користете рачни поставки",
     "Password required" : "Потребна е лозинка",
     "Testing authentication" : "Тестирање на автентикација",
+    "Loading account" : "Вчирување на сметка",
     "Account updated" : "Сметката е ажурирана",
     "IMAP server is not reachable" : "IMAP серверот не е достапен",
     "SMTP server is not reachable" : "SMTP серверот не е достапен",
@@ -64,6 +69,9 @@ OC.L10N.register(
     "Writing mode" : "Режим на пишување",
     "Preferred writing mode for new messages and replies." : "Претпочитан режим на пишување за нови пораки и одговори.",
     "Default folders" : "Стандардни папки",
+    "Automatic trash deletion" : "Автоматско бришење на корпата со отпадоци",
+    "Days after which messages in Trash will automatically be deleted:" : "Денови по кои пораките во корпата автоматски ќе се избришат:",
+    "Autoresponder" : "Автоматски одговор",
     "Trusted senders" : "Доверливи испраќачи",
     "Mail server" : "Сервер за е-пошта",
     "Update alias" : "Ажурирај алијас",
@@ -81,6 +89,12 @@ OC.L10N.register(
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
     "Automatically classify importance of new email" : "Автоматски класификација на важноста на новите пораки",
     "Could not update preference" : "Неможе да се ажурираат параметрите",
+    "Select an alias" : "Избери алијас",
+    "Update Certificate" : "Ажурирај сертификат",
+    "No certificate" : "Нема сертификат",
+    "Certificate updated" : "Сертификатот е ажуриран",
+    "Could not update certificate" : "Неможе да се ажурира сертификатот",
+    "{commonName} - Valid until {expiryDate}" : "{commonName} - Валиден до {expiryDate}",
     "From" : "Од",
     "Select account" : "Избете сметка",
     "To" : "До",
@@ -92,6 +106,7 @@ OC.L10N.register(
     "Subject" : "Наслов",
     "Subject …" : "Наслов ...",
     "This message came from a noreply address so your reply will probably not be read." : "Оваа порака е испратена од адреса што е назначена без одговор, така што вашиот одговор веројатно нема да биде прочитан.",
+    "The following recipients do not have a S/MIME certificate: {recipients}." : "Следниве примачи не поседуваат S/MIME сертификат: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "Следниве примачи не поседуваат PGP клуч: {recipients}.",
     "Write message …" : "Напиши порака ...",
     "Saving draft …" : "Зачувување како нацрт ...",
@@ -105,14 +120,20 @@ OC.L10N.register(
     "Enable formatting" : "Овозможи форматирање",
     "Disable formatting" : "Оневозможи форматирање",
     "Request a read receipt" : "Побарај потврда за прочитана порака",
+    "Sign message with S/MIME" : "Потпиши ја пораката со S/MIME",
+    "Encrypt message with S/MIME" : "Шифрирај порака со S/MIME",
     "Encrypt message with Mailvelope" : "Шифрирај порака со Mailvelope",
     "Send now" : "Испрати сега",
     "Tomorrow morning" : "Утре сабајле",
     "Tomorrow afternoon" : "Утре попладне",
     "Monday morning" : "Понеделник наутро",
     "Custom date and time" : "Одреден датум и време",
-    "Enter a date" : "Внесете датум",
+    "Enter a date" : "Внеси датум",
     "Add share link from {productName} Files" : "Додади линк со споделување од {productName} датотеките",
+    "Encrypt with S/MIME and send later" : "Шифрирај со S/MIME и испрати ја подоцна",
+    "Encrypt with S/MIME and send" : "Шифрирај со S/MIME и испрати",
+    "Encrypt with Mailvelope and send later" : "Шифрирај со Mailvelope и испрати ја подоцна",
+    "Encrypt with Mailvelope and send" : "Шифрирај со Mailvelope и испрати",
     "Send" : "Прати",
     "Message {id} could not be found" : "Пораката {id} не е пронајдена",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Сите постоечки форматирања (како пример: болд, потцртан текст, италик итн.) ќе бидат отстранети.",
@@ -123,16 +144,15 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Избери датотека за да се сподели како линк",
     "_{count} attachment_::_{count} attachments_" : ["{count} прилог","{count} прилози"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Прилогот ја надминува најголемата дозволена големина за прилози од {size}. Споделете го прилогот со линк.","Прилозите ја надминуваат најголемата дозволена големина за прилози од {size}. Споделете ги прилозите со линк."],
+    "Untitled message" : "Неименувана порака",
     "Confirm" : "Потврди",
-    "No message found yet" : "Не се пронајдени пораки",
-    "Set up an account" : "Постави сметка",
     "Plain text" : "Обичен текст",
     "Rich text" : "Богат текст",
     "No messages in this mailbox" : "Нема пораки во ова сандаче",
     "No messages" : "Нема пораки",
     "Draft: " : "Шаблон:",
     "This message is unread" : "Оваа порака не е прочитана",
-    "Favorite" : "Омилен",
+    "Favorite" : "Омилени",
     "Unread" : "Непрочитана",
     "Read" : "Прочитана",
     "Unimportant" : "Неважна",
@@ -149,6 +169,10 @@ OC.L10N.register(
     "Download message" : "Преземи порака",
     "Blind copy recipients only" : "Само приматели на слепи копии",
     "No subject" : "Нема наслов",
+    "Set reminder for later today" : "Постави потсетник за денес покасно",
+    "Set reminder for tomorrow" : "Постави потсетник за утре",
+    "Set reminder for this weekend" : "Постави потсетник за овој викенд",
+    "Set reminder for next week" : "Постави потсетник за наредната недела",
     "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
     "Could not delete message" : "Неможе да се избрише пораката",
     "Forward" : "Препрати",
@@ -193,7 +217,6 @@ OC.L10N.register(
     "Forward message as attachment" : "Препрати ја пораката како прилог",
     "View source" : "Погледни извор",
     "Download thread data for debugging" : "Преземи информации за развивачи",
-    "Message source" : "Извор на пораката",
     "Message body" : "Тело на пораката",
     "Import into calendar" : "Увези во календар",
     "Download attachment" : "Преземи прилог",
@@ -236,11 +259,14 @@ OC.L10N.register(
     "Mark all messages of this mailbox as read" : "Означи ги како прочитани сите пораки од ова сандаче ",
     "Add submailbox" : "Додади подсандаче",
     "Edit name" : "Уреди име",
+    "Move mailbox" : "Премести сандаче",
     "Clear cache" : "Избриши го кешот",
     "Clear locally cached data, in case there are issues with synchronization." : "Исчистете ги локално зачуваните податоци, во случај да има проблеми со синхронизацијата.",
     "Subscribed" : "Претплатени",
     "Sync in background" : "Синхронизација во позадина",
+    "Clear mailbox" : "Исчисти сандаче",
     "Delete mailbox" : "Избриши сандаче",
+    "Clear mailbox {name}" : "Исчисти сандаче {name}",
     "The mailbox and all messages in it will be deleted." : "Сандачето и сеите пораки во него ќе бидат избришани.",
     "Delete mailbox {name}" : "Избриши сандаче {name}",
     "An error occurred, unable to rename the mailbox." : "Настана грешка, неможе да се промени името на сандачето.",
@@ -260,6 +286,7 @@ OC.L10N.register(
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Се обидувате да испратите до многу примачи во До и/или Cc. Можете да користите Bcc за да ги скриете адресите на примачите.",
     "Message discarded" : "Пораката е отфрлена",
     "Could not discard message" : "Неможе да се отфрли порака",
+    "Welcome to {cloudName} Mail" : "Добредојдовте во {cloudName} е-пошта",
     "Autoresponder off" : "Исклучен автоматски одговор",
     "Autoresponder on" : "Вклучен автоматски одговор",
     "First day" : "Прв ден",
@@ -279,8 +306,13 @@ OC.L10N.register(
     "Add" : "Додади",
     "Search in mailbox" : "Барај во сандачето",
     "Close" : "Затвори",
+    "Search parameters" : "Параметри за пребарување",
     "Pick a start date" : "Избери почетен датум",
-    "Pick an end date" : "Избери датум на завршување",
+    "Pick an end date" : "Избери краен датум",
+    "Select senders" : "Избери испраќачи",
+    "Select recipients" : "Избери примачи",
+    "Select CC recipients" : "Избери CC примачи",
+    "Select BCC recipients" : "Избери BCC примачи",
     "Tags" : "Ознаки",
     "Select tags" : "Избери ознаки",
     "Marked as" : "Означено како",
@@ -303,20 +335,23 @@ OC.L10N.register(
     "Signature …" : "Потпис ...",
     "Save signature" : "Зачувај потпис",
     "Place signature above quoted text" : "Постави го потписот над цитираниот текст",
-    "Add default tags" : "Додади стандардни ознаки",
-    "Rename tag" : "Преимени ознака",
     "Saving new tag name …" : "Зачувување на ново име на ознака ...",
+    "An error occurred, unable to rename the tag." : "Настана грешка, неможе да се преименува ознака.",
+    "Add default tags" : "Додади стандардни ознаки",
     "Add tag" : "Додади ознака",
     "Saving tag …" : "Зачувување ознака …",
     "Tag name is a hidden system tag" : "Името на ознаката е сокриена системска ознака",
     "Tag already exists" : "Тагот веќе постои",
     "An error occurred, unable to create the tag." : "Настана грешка, неможе да се креира ознака.",
-    "An error occurred, unable to rename the tag." : "Настана грешка, неможе да се преименува ознака.",
+    "Select calendar" : "Избери календар",
     "Not found" : "Не е пронајдено",
     "Could not load your message thread" : "Неможат да се преземат информации за пораката",
+    "Mark as unfavorite" : "Од-означи омилена",
+    "Mark as favorite" : "Означи како омилена",
     "Mark as unread" : "Означи како непрочитано",
     "Mark as read" : "Означи како прочитано",
     "Delete message" : "Избриши порака",
+    "Message source" : "Извор на пораката",
     "Remove" : "Отстрани ",
     "individual" : "индивидуално",
     "domain" : "домен",
@@ -333,6 +368,7 @@ OC.L10N.register(
     "Mail app" : "Апликација Електронска пошта",
     "The mail app allows users to read mails on their IMAP accounts." : "Апликацијата за електронска пошта дозволува на корисниците да ги читаат својте пораки од IMAP сметки.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Овде може да се пронајде поопшитно прилагодување. Специфични параметри за корисниците може да се пронајдат во самата апликација (доле-лево).",
+    "Gmail integration" : "Gmail интеграција",
     "Microsoft integration" : "Microsoft интеграција",
     "Reset" : "Ресетирање",
     "Client ID" : "Клиент ИД",
@@ -367,6 +403,8 @@ OC.L10N.register(
     "Account connected" : "Сметката е поврзана",
     "You can close this window" : "Можете да го затворите овој прозорец",
     "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
+    "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
+    "Later today – {timeLocale}" : "Денес покасно – {timeLocale}",
     "Itinerary for {type} is not supported yet" : "Итинерар за {type} сеуште не е поддржан",
     "All" : "Сите",
     "Drafts" : "Шаблони",
@@ -381,6 +419,9 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n нова порака \nод {from}","%n нови пораки\nод {from}"],
     "Nextcloud Mail" : "Електронска пошта",
+    "Discard changes" : "Орфрли промени",
+    "Discard unsaved changes" : "Отфрли ги назачуваните промени",
+    "Keep editing message" : "Продолжи со уредување на порака",
     "Attachments were not copied. Please add them manually." : "Пролозите на се копирани. Додадете ги рачно.",
     "Message sent" : "Пораката е испратена",
     "Could not send message" : "Неможе да се испрати порака",
