@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Innebygd melding %s",
     "Important mail" : "Viktig e-post",
+    "No message found yet" : "Ingen meldinger funnet enda",
+    "Set up an account" : "Sett opp en konto",
     "Unread mail" : "Ulest e-post",
     "Important" : "Viktig",
     "Work" : "Arbeid",
@@ -77,6 +79,8 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
     "Register as application for mail links" : "Registrer som applikasjon for e-postlenker",
     "Show keyboard shortcuts" : "Vis tastatursnarveier",
+    "Newest" : "Nyeste",
+    "Oldest" : "Eldst",
     "Looking for a way to encrypt your emails?" : "Leter du etter en måte å kryptere e-postene dine på?",
     "Install Mailvelope browser extension here" : "Installer Mailvelope nettleserutvidelse her",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillat at appen samler inn data om interaksjonene dine. Basert på disse dataene vil appen tilpasse seg dine preferanser. Dataene vil kun bli lagret lokalt.",
@@ -121,8 +125,6 @@ OC.L10N.register(
     "_{count} attachment_::_{count} attachments_" : ["{count} vedlegg","{count} vedlegg"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Vedlegget overskrider den tillatte vedleggsstørrelsen på {size}. Vennligst del filen via lenke i stedet.","Vedleggene overskrider den tillatte vedleggsstørrelsen på {size}. Vennligst del filene via lenke i stedet."],
     "Confirm" : "Bekreft",
-    "No message found yet" : "Ingen meldinger funnet enda",
-    "Set up an account" : "Sett opp en konto",
     "Plain text" : "Ren tekst",
     "Rich text" : "Rik tekst",
     "No messages in this mailbox" : "Ingen meldinger i denne postboksen",
@@ -196,7 +198,6 @@ OC.L10N.register(
     "Forward message as attachment" : "Videresend melding som et vedlegg",
     "View source" : "Vis kilde",
     "Download thread data for debugging" : "Last ned tråddata for feilsøking",
-    "Message source" : "Melding kilde",
     "Message body" : "Meldingstekst",
     "Import into calendar" : "Importer til kalender",
     "Download attachment" : "Last ned vedlegg",
@@ -279,6 +280,7 @@ OC.L10N.register(
     "Contact name …" : "Kontakt navn ...",
     "Add" : "Legg til",
     "Close" : "Lukk",
+    "Body" : "Kropp",
     "Tags" : "Merkelapper",
     "Select tags" : "Velg merkelapper",
     "Clear" : "Tøm",
@@ -299,20 +301,21 @@ OC.L10N.register(
     "Signature …" : "Signatur ...",
     "Save signature" : "Lagre signatur",
     "Place signature above quoted text" : "Plasser signatur over sitert tekst",
-    "Add default tags" : "Legg til standardtags",
-    "Rename tag" : "Gi nytt navn til taggen",
+    "Delete tag" : "Slett merke",
     "Saving new tag name …" : "Lagrer nytt tagnavn …",
+    "An error occurred, unable to rename the tag." : "Det oppsto en feil, kan ikke gi nytt navn til taggen.",
+    "Add default tags" : "Legg til standardtags",
     "Add tag" : "Legg til merkelapp",
     "Saving tag …" : "Lagrer tag …",
     "Tag name is a hidden system tag" : "Tagnavn er en skjult systemtag",
     "Tag already exists" : "Merkelappen finnes allerede",
     "An error occurred, unable to create the tag." : "Det oppsto en feil, kan ikke opprette taggen.",
-    "An error occurred, unable to rename the tag." : "Det oppsto en feil, kan ikke gi nytt navn til taggen.",
     "Not found" : "Ikke funnet",
     "Could not load your message thread" : "Kunne ikke laste meldingstråden din",
     "Mark as unread" : "Merk som ulest",
     "Mark as read" : "Merk som lest",
     "Delete message" : "Slett melding",
+    "Message source" : "Melding kilde",
     "Remove" : "Fjern",
     "No senders are trusted at the moment." : "Ingen avsendere er klarert for øyeblikket.",
     "Could not remove trusted sender {sender}" : "Kunne ikke fjerne pålitelig avsender {sender}",
