@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Ingebed bericht %s",
     "Important mail" : "Belangrijke mail",
+    "No message found yet" : "Nog geen berichten gevonden",
+    "Set up an account" : "Maak een account aan",
     "Unread mail" : "Ongelezen mail",
     "Important" : "Belangrijk",
     "Work" : "Werk",
@@ -97,8 +99,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Kies een bestand om als link te delen",
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["De bijlage overschrijdt de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link.","De bijlagen overschrijden de toegestane omvang van {size}. Deel de bestanden in plaats daarvan via een link."],
     "Confirm" : "Bevestigen",
-    "No message found yet" : "Nog geen berichten gevonden",
-    "Set up an account" : "Maak een account aan",
     "Plain text" : "Platte tekst",
     "Rich text" : "Rijke tekst",
     "No messages in this mailbox" : "Geen berichten in deze inbak",
@@ -163,7 +163,6 @@ OC.L10N.register(
     "Move message" : "Verplaats bericht",
     "View source" : "Bekijk bron",
     "Download thread data for debugging" : "Download draadgegevens voor debuggen",
-    "Message source" : "Bericht brontekst",
     "Message body" : "Berichttekst",
     "Import into calendar" : "Toevoegen aan agenda",
     "Download attachment" : "Download bijlage",
@@ -238,6 +237,7 @@ OC.L10N.register(
     "Contact name …" : "Naam contactpersoon ...",
     "Add" : "Toevoegen",
     "Close" : "Sluit",
+    "Body" : "Body",
     "Tags" : "Tags",
     "Select tags" : "Kies tags",
     "Clear" : "Terug",
@@ -258,20 +258,21 @@ OC.L10N.register(
     "Signature …" : "Handtekening ...",
     "Save signature" : "Handtekening opslaan",
     "Place signature above quoted text" : "Plaats handtekening boven de aangehaalde tekst",
-    "Add default tags" : "Voeg standaard tags toe",
-    "Rename tag" : "Hernoem tag",
+    "Delete tag" : "Verwijderen tag",
     "Saving new tag name …" : "Sla nieuw tag op ...",
+    "An error occurred, unable to rename the tag." : "Er is een fout opgetreden, kan tag niet hernoemen",
+    "Add default tags" : "Voeg standaard tags toe",
     "Add tag" : "Toevoegen tag",
     "Saving tag …" : "Opslaan tag ...",
     "Tag already exists" : "Markering bestaat al",
     "An error occurred, unable to create the tag." : "Er trad een fout op, tag kon niet worden gecreëerd.",
-    "An error occurred, unable to rename the tag." : "Er is een fout opgetreden, kan tag niet hernoemen",
     "Not found" : "Niet gevonden",
     "Could not load your message thread" : "Kon je berichtendraad niet laden",
     "Unsubscribe" : "Afmelden",
     "Mark as unread" : "Markeren als ongelezen",
     "Mark as read" : "Markeren als gelezen",
     "Delete message" : "Bericht verwijderen",
+    "Message source" : "Bericht brontekst",
     "Remove" : "Verwijderen",
     "No senders are trusted at the moment." : "Er zijn nu geen vertrouwder afzenders.",
     "Could not remove trusted sender {sender}" : "Kon vertrouwde afzender niet verwijderen {afzender}",
