@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Встроенное сообщение %s",
     "Important mail" : "Важная почта",
+    "No message found yet" : "Сообщений ещё нет",
+    "Set up an account" : "Настроить учётную запись",
     "Unread mail" : "Непрочитанная почта",
     "Important" : "Важное",
     "Work" : "Работа",
@@ -10,6 +12,8 @@ OC.L10N.register(
     "To Do" : "Задачи",
     "Later" : "Позже",
     "Mail" : "Почта",
+    "You are reaching your mailbox quota limit for {account_email}" : "Вы достигли предела квоты почтового ящика для {account_email}",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "В настоящее время вы используете {percentage} места в вашем почтовом ящике. Пожалуйста, освободите место, удалив ненужные электронные письма.",
     "Mails" : "Почты",
     "💌 A mail app for Nextcloud" : "💌 Почта для Nextcloud",
     "Your session has expired. The page will be reloaded." : "Истекло время сеанса работы, страница будет обновлена.",
@@ -17,6 +21,8 @@ OC.L10N.register(
     "Sent messages are saved in:" : "Папка отправленных писем:",
     "Deleted messages are moved in:" : "Папка для удалённых писем:",
     "Archived messages are moved in:" : "Папка архива писем:",
+    "Snoozed messages are moved in:" : "Отложенные сообщения перемещаются в:",
+    "Junk messages are saved in:" : "Нежелательные сообщения сохраняются в:",
     "Auto" : "Автоматически",
     "Name" : "Имя",
     "Mail address" : "Почтовый адрес",
@@ -41,13 +47,19 @@ OC.L10N.register(
     "SMTP Password" : "Пароль SMTP",
     "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Для настройки учётной записи Google необходимо включить двухфакторную аутентификацию и создать пароль приложения.",
     "Connecting" : "Подключение",
+    "Reconnect Google account" : "Переподключите аккаунт Google",
     "Sign in with Google" : "Войти через Google",
     "Save" : "Сохранить",
     "Connect" : "Подключиться",
+    "Looking up configuration" : "Поиск конфигурации",
     "Checking mail host connectivity" : "Проверка подключения почтового сервера",
     "Configuration discovery failed. Please use the manual settings" : "Не удалось автоматически настроить конфигурацию, введите параметры вручную.",
     "Password required" : "Требуется аутентификация",
     "Testing authentication" : "Проверка аутентификации",
+    "Awaiting user consent" : "Ожидание согласия пользователя",
+    "Account created. Please follow the pop-up instructions to link your Google account" : "Аккаунт создан. Следуйте инструкциям во всплывающем окне, чтобы связать свою учетную запись Google",
+    "Loading account" : "Загрузка аккаунта",
+    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Аккаунт обновлен. Следуйте инструкциям во всплывающем окне, чтобы повторно подключить свою учетную запись Google",
     "Account updated" : "Аккаунт обновлен",
     "IMAP server is not reachable" : "Сервер IMAP недоступен",
     "SMTP server is not reachable" : "SMTP сервер недоступен",
@@ -55,20 +67,28 @@ OC.L10N.register(
     "SMTP username or password is wrong" : "Неверное имя пользователя или пароль SMTP",
     "IMAP connection failed" : "Не удалось установить соединение IMAP",
     "SMTP connection failed" : "Не удалось установить SMTP соединение",
+    "Authorization pop-up closed" : "Всплывающее окно авторизации закрыто",
+    "Configuration discovery temporarily not available. Please try again later." : "Обнаружение конфигурации временно недоступно. Пожалуйста, повторите попытку позже.",
     "There was an error while setting up your account" : "При настройке вашей учетной записи произошла ошибка",
     "Account settings" : "Параметры учётной записи",
     "Aliases" : "Псевдонимы",
+    "Alias to S/MIME certificate mapping" : "Сопоставление псевдонима с сертификатом S/MIME",
     "Signature" : "Подпись",
     "A signature is added to the text of new messages and replies." : "Подпись будет добавлена к тексту новых писем и при написании ответов.",
     "Writing mode" : "Режим написания",
     "Preferred writing mode for new messages and replies." : "Предпочтительный режим для создания новых писем и ответов.",
     "Default folders" : "Папки по умолчанию",
+    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Папки, которые будут использоваться для черновиков, отправленных сообщений, удаленных сообщений, архивированных сообщений и нежелательных сообщений.",
+    "Automatic trash deletion" : "Автоматическое удаление мусора",
+    "Days after which messages in Trash will automatically be deleted:" : "Дни, после которых сообщения в Корзине будут автоматически удаляться:",
     "Autoresponder" : "Автоответчик",
+    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматический ответ на входящие сообщения. Если кто-то отправит вам несколько сообщений, этот автоматический ответ будет отправляться не чаще одного раза в 4 дня.",
     "Sieve filter rules" : "Правила sieve фильтра",
     "Trusted senders" : "Доверенные отправители",
     "Mail server" : "Почтовый сервер",
     "Sieve filter server" : "Сервер sieve фильтра",
     "Update alias" : "Обновить псевдоним",
+    "Rename alias" : "Переименовать псевдоним",
     "Show update alias form" : "Показать обновления для формы alias",
     "Delete alias" : "Удалить псевдоним",
     "Go back" : "Вернуться назад",
@@ -82,12 +102,19 @@ OC.L10N.register(
     "Register as application for mail links" : "Зарегистрировать в качестве приложения для обработки почтовых ссылок",
     "Show keyboard shortcuts" : "Показать справку о комбинациях клавиш",
     "Manage S/MIME certificates" : "Управление сертификатами S/MIME",
+    "Newest" : "Более новые",
+    "Oldest" : "Более старые",
     "Looking for a way to encrypt your emails?" : "Необходимо использовать шифрование электронных писем?",
     "Install Mailvelope browser extension here" : "Установите расширение для браузера Mailvelope здесь",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешить приложению собирать данные о взаимодействии.  Основываясь на этих данных, приложение адаптируется к вашим предпочтениям. Данные будут храниться только локально.",
     "Put my text to the bottom of a reply instead of on top of it." : "Поместить мой текст внизу ответа, а не поверх него.",
     "Automatically classify importance of new email" : "Автоматически определять важность новых писем",
     "Could not update preference" : "Не удалось обновить свойство",
+    "Select an alias" : "Выберите псевдоним",
+    "Update Certificate" : "Обновить сертификат",
+    "No certificate" : "Нет сертификата",
+    "Certificate updated" : "Сертификат обновлен",
+    "Could not update certificate" : "Не удалось обновить сертификат",
     "{commonName} - Valid until {expiryDate}" : "{commonName} — истекает {expiryDate}",
     "From" : "От",
     "Select account" : "Выбрать аккаунт",
@@ -100,6 +127,7 @@ OC.L10N.register(
     "Subject" : "Тема",
     "Subject …" : "Тема…",
     "This message came from a noreply address so your reply will probably not be read." : "Это сообщение было отправлено с адреса, не предусматривающего получения ответов. Ваше сообщение, направленное на этот адрес, возможно никогда не будет прочитано.",
+    "The following recipients do not have a S/MIME certificate: {recipients}." : "Следующие получатели не имеют сертификата S/MIME: {recipients}.",
     "The following recipients do not have a PGP key: {recipients}." : "У следующих получателей отсутствуют ключи PGP: {recipients}.",
     "Write message …" : "Напишите сообщение…",
     "Saving draft …" : "Сохранение черновика…",
@@ -109,10 +137,13 @@ OC.L10N.register(
     "Discard & close draft" : "Отменить изменения и закрыть черновик",
     "Upload attachment" : "Загрузить файл с ПК",
     "Add attachment from Files" : "Из приложения «Файлы»",
+    "Smart picker" : "Умный подборщик",
     "Send later" : "Отправить позже",
     "Enable formatting" : "Использовать форматирование",
     "Disable formatting" : "Выключить форматирование",
     "Request a read receipt" : "Запросить подтверждение прочтения",
+    "Sign message with S/MIME" : "Подписать сообщение с помощью S/MIME",
+    "Encrypt message with S/MIME" : "Зашифровать сообщение с помощью S/MIME",
     "Encrypt message with Mailvelope" : "Зашифровать сообщение при помощи приложения Mailvelope",
     "Send now" : "Отправить сейчас",
     "Tomorrow morning" : "Завтра утром",
@@ -121,23 +152,29 @@ OC.L10N.register(
     "Custom date and time" : "Настроить дату и время",
     "Enter a date" : "Выберите дату",
     "Add share link from {productName} Files" : "Добавить ссылку для общего доступа из приложения Файлы для {productName}",
+    "Encrypt with S/MIME and send later" : "Зашифруйте с помощью S/MIME и отправьте позже",
+    "Encrypt with S/MIME and send" : "Зашифруйте с помощью S/MIME и отправить",
+    "Encrypt with Mailvelope and send later" : "Зашифруйте с помощью Mailvelope и отправьте позже",
+    "Encrypt with Mailvelope and send" : "Зашифруйте с помощью Mailvelope и отправьте",
     "Send" : "Отправить",
     "Message {id} could not be found" : "Не удалось найти сообщение {id}",
+    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Был выбран вариант «Подписать или зашифровать с помощью S/MIME», но у нас нет сертификата для выбранного псевдонима. Сообщение не будет подписано или зашифровано.",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Любое существующее форматирование (например, жирный шрифт, курсив, подчеркивание или встроенные изображения) будет удалено.",
     "Turn off formatting" : "Отключить форматирование",
+    "Turn off and remove formatting" : "Отключить и удалить форматирование",
     "Keep formatting" : "Сохранить форматирование",
     "Choose a file to add as attachment" : "Выбрать файл для вложения",
     "Choose a file to share as a link" : "Выберите файл для публикации ссылкой",
     "_{count} attachment_::_{count} attachments_" : ["{count} вложение","{count} вложения","{count} вложений","{count} вложений"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Размер этого вложения превышает установленный лимит. Опубликуйте этот файл с доступом по ссылке и перешлите ссылку, вместо отправки файла.","Размер этих вложений превышает установленный лимит. Опубликуйте эти файы с доступом по ссылке и перешлите ссылку, вместо отправки файла.","Размер этих вложений превышает установленный лимит. Опубликуйте эти файы с доступом по ссылке и перешлите ссылку, вместо отправки файла.","Размер этих вложений превышает установленный лимит. Опубликуйте эти файы с доступом по ссылке и перешлите ссылку, вместо отправки файла."],
+    "Untitled message" : "Сообщение без названия",
     "Confirm" : "Подтвердить",
-    "No message found yet" : "Сообщений ещё нет",
-    "Set up an account" : "Настроить учётную запись",
     "Plain text" : "Простой текст",
     "Rich text" : "Текст с форматированием",
     "No messages in this mailbox" : "В этой папке нет сообщений",
     "No messages" : "Нет ни одного сообщения",
     "Draft: " : "Черновик:",
+    "Encrypted message" : "Зашифрованное сообщение",
     "This message is unread" : "Это сообщение не прочитано",
     "Unfavorite" : "Убрать из избранного",
     "Favorite" : "В избранное",
@@ -185,6 +222,7 @@ OC.L10N.register(
     "Event created" : "Событие создано",
     "Could not create event" : "Не удалось создать событие",
     "You accepted this invitation" : "Вы приняли приглашение",
+    "You tentatively accepted this invitation" : "Вы предварительно приняли это приглашение",
     "You declined this invitation" : "Вы отклонили приглашение",
     "You already reacted to this invitation" : "Вы уже отреагировали на это приглашение",
     "You have been invited to an event" : "Вы были приглашены на мероприятие",
@@ -193,11 +231,15 @@ OC.L10N.register(
     "Comment" : "Комментарий",
     "Accept" : "Принять",
     "Decline" : "Отклонить",
+    "Tentatively accept" : "Предварительно принять",
     "More options" : "Дополнительные параметры",
     "This event was updated" : "Событие было обновлено",
+    "{attendeeName} accepted your invitation" : "Пользователь {attendeeName} принял ваше приглашение",
+    "{attendeeName} tentatively accepted your invitation" : "Пользователь {attendeeName} предварительно принял ваше приглашение",
     "Could not open mailbox" : "Невозможно открыть папку",
     "Loading messages …" : "Загрузка сообщений...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Выполняется индексация сообщений, это займёт некоторое время.",
+    "To archive a message please configure an archive mailbox in account settings" : "Чтобы заархивировать сообщение, настройте архивный почтовый ящик в настройках учетной записи.",
     "Choose target mailbox" : "Выберите папку",
     "No more submailboxes in here" : "Вложенные папки отсутствуют",
     "Choose" : "Выберите",
@@ -215,7 +257,6 @@ OC.L10N.register(
     "Forward message as attachment" : "Переслать сообщение вложением",
     "View source" : "Просмотреть исходный текст",
     "Download thread data for debugging" : "Скачать ветку для отладки",
-    "Message source" : "Исходный текст сообщения",
     "Message body" : "Тело сообщения",
     "Import into calendar" : "Импортировать в календарь",
     "Download attachment" : "Скачать вложение",
@@ -224,6 +265,7 @@ OC.L10N.register(
     "Embedded message" : "Внедрённое сообщение",
     "Next week – {timeLocale}" : "Следующая неделя – {timeLocale}",
     "Choose a folder to store the attachment in" : "Выберите каталог для хранения вложений",
+    "calendar imported" : "календарь импортирован",
     "Save all to Files" : "Сохранить все в файлы",
     "Download Zip" : "Скачать в архиве ZIP",
     "Choose a folder to store the attachments in" : "Выбрать папку для сохранения вложений",
@@ -240,9 +282,12 @@ OC.L10N.register(
     "Moving thread" : "Перемещение ветки",
     "Moving message" : "Сообщение перемещается",
     "Mail settings" : "Параметры эл. почты",
+    "Provisioned account is disabled" : "Предоставленный аккаунт отключен",
+    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Пожалуйста, войдите в систему, используя пароль, чтобы активировать эту учетную запись. Текущий сеанс использует аутентификацию без пароля, например. Единый вход или WebAuthn.",
     "Quota" : "Квота",
     "Show only subscribed mailboxes" : "Показать только папки из подписки",
     "Add mailbox" : "Добавить папку",
+    "Mailbox name" : "Имя почтового ящика",
     "Saving" : "Сохранение",
     "Move up" : "Переместить выше",
     "Move down" : "Переместить ниже",
@@ -260,11 +305,15 @@ OC.L10N.register(
     "Mark all messages of this mailbox as read" : "Пометить все сообщения в папке как прочитанные",
     "Add submailbox" : "Добавить вложенную папку",
     "Edit name" : "Изменить название",
+    "Move mailbox" : "Переместить почтовый ящик",
     "Clear cache" : "Очистить кеш",
     "Clear locally cached data, in case there are issues with synchronization." : "Очистить локальный кеш данных в случае проблем с синхронизацией.",
     "Subscribed" : "Подписано",
     "Sync in background" : "Фоновая синхронизация",
+    "Clear mailbox" : "Очистить почтовый ящик",
     "Delete mailbox" : "Удалить папку",
+    "All messages in mailbox will be deleted." : "Все сообщения в почтовом ящике будут удалены.",
+    "Clear mailbox {name}" : "Очистить почтовый ящик {name}",
     "The mailbox and all messages in it will be deleted." : "Папка и все письма в ней будут удалены.",
     "Delete mailbox {name}" : "Удалить папку {name}",
     "An error occurred, unable to rename the mailbox." : "Ошибка переименования папки.",
@@ -281,12 +330,24 @@ OC.L10N.register(
     "Send anyway" : "Все равно отправить",
     "Edit message" : "Редактировать сообщение",
     "Draft" : "Черновик",
+    "Message saved" : "Сообщение сохранено",
+    "Failed to save message" : "Не удалось сохранить сообщение",
+    "Failed to save draft" : "Не удалось сохранить черновик",
+    "attachment" : "вложение",
+    "attached" : "прикрепить",
     "No sent mailbox configured. Please pick one in the account settings." : "Не настроена папка исходящих сообщений. Выберите ее в параметрах учётной записи.",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Вы пытаетесь отправить письмо очень большому количеству получателей, указанных в полях «Кому» или «Коп». Для сокрытия адреса эл. почты получателя, укажите его в поле «Скр. коп.».",
+    "You mentioned an attachment. Did you forget to add it?" : "Вы упомянули вложение. Вы забыли добавить его?",
     "Message discarded" : "Внесение изменений отменено",
     "Could not discard message" : "Не удалось отменить внесение изменений",
+    "Welcome to {cloudName} Mail" : "Добро пожаловать в {cloudName} Mail",
+    "Autoresponder off" : "Автоответчик выключен",
+    "Autoresponder on" : "Автоответчик включен",
+    "First day" : "Первый день",
+    "Last day (optional)" : "Последний день (необязательно)",
     "Message" : "Сообщение",
     "Oh Snap!" : "Ого!",
+    "Save autoresponder" : "Сохранить автоответчик",
     "Could not open outbox" : "Не удалось открыть исходящие",
     "Pending or not sent messages will show up here" : "В этой папке будут представлены отложенные и неотправленные сообщения",
     "Delete" : "Удалить",
@@ -298,9 +359,20 @@ OC.L10N.register(
     "Copy to clipboard" : "Копировать в буфер",
     "Contact name …" : "Имя контакта …",
     "Add" : "Добавить",
+    "Copied email address to clipboard" : "Адрес электронной почты скопирован в буфер обмена.",
+    "Could not copy email address to clipboard" : "Не удалось скопировать адрес электронной почты в буфер обмена.",
+    "Search in mailbox" : "Искать в почтовом ящике",
     "Close" : "Закрыть",
+    "Search parameters" : "Параметры поиска",
+    "Body" : "Тело",
+    "Pick a start date" : "Выберите дату начала",
+    "Pick an end date" : "Выберите дату окончания",
+    "Select senders" : "Выберите отправителей",
+    "Select recipients" : "Выберите получателей",
     "Tags" : "Метки",
     "Select tags" : "Выбор меток",
+    "Marked as" : "Отмечено как",
+    "Has attachments" : "Имеет вложения",
     "Clear" : "Очистить",
     "Search" : "Поиск",
     "Date" : "Дата",
@@ -316,24 +388,54 @@ OC.L10N.register(
     "Sieve Password" : "Sieve пароль",
     "Save sieve settings" : "Сохранить настройки sieve",
     "Save sieve script" : "Сохранить sieve скрипт",
+    "The syntax seems to be incorrect:" : "Синтаксис кажется неправильным:",
     "This weekend – {timeLocale}" : "Эти выходные – {timeLocale}",
     "Signature …" : "Подпись...",
+    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Размер вашей подписи превышает 2 МБ. Это может повлиять на производительность вашего редактора.",
     "Save signature" : "Сохранить подпись",
     "Place signature above quoted text" : "Размещать подпись над цитируемым текстом",
-    "Add default tags" : "Добавить метки по умолчанию",
-    "Rename tag" : "Переименовать метку",
+    "Edit name or color" : "Отредактируйте название или цвет",
+    "Delete tag" : "Удалить метку",
     "Saving new tag name …" : "Сохранение нового названия метки…",
+    "Set tag" : "Установить тег",
+    "Unset tag" : "Неустановленный тег",
+    "An error occurred, unable to rename the tag." : "Не удалось переименовать метку.",
+    "Add default tags" : "Добавить метки по умолчанию",
     "Add tag" : "Добавить метку",
     "Saving tag …" : "Сохранение метки…",
+    "Tag name is a hidden system tag" : "Имя тега является скрытым системным тегом",
     "Tag already exists" : "Метка уже существует",
     "An error occurred, unable to create the tag." : "Не удалось создать метку.",
-    "An error occurred, unable to rename the tag." : "Не удалось переименовать метку.",
+    "Select calendar" : "Выбрать календарь",
+    "No calendars with task list support" : "Нет календарей с поддержкой списка задач",
+    "Task created" : "Задача создана",
+    "Could not create task" : "Не удалось создать задачу",
     "Not found" : "Не найдено",
     "Could not load your message thread" : "Ошибка загрузки ветки переписки",
     "Unsubscribe" : "Отписаться",
+    "Mark as favorite" : "Отметить как избранное",
     "Mark as unread" : "Отметить не прочитанным",
     "Mark as read" : "Отметить прочитанным",
+    "Archive message" : "Архивное сообщение",
     "Delete message" : "Удалить сообщение",
+    "Message source" : "Исходный текст сообщения",
+    "Unsubscribe via link" : "Отписаться по ссылке",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "Отказ от подписки приведет к остановке всех сообщений из списка рассылки {sender}",
+    "Send unsubscribe email" : "Отправить письмо об отказе от подписки",
+    "Unsubscribe via email" : "Отписаться по эл. почте",
+    "Encrypted & verified " : "Зашифровано и проверено",
+    "Signature verified" : "Подпись проверена",
+    "Signature unverified " : "Подпись не проверена",
+    "This message was encrypted by the sender before it was sent." : "Это сообщение было зашифровано отправителем перед отправкой.",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Это сообщение содержит проверенную цифровую подпись S/MIME. Сообщение не менялось с момента отправки.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Это сообщение содержит непроверенную цифровую подпись S/MIME. Возможно, сообщение было изменено с момента его отправки, или сертификат подписавшего не является доверенным.",
+    "Unsubscribe request sent" : "Запрос на отмену подписки отправлен",
+    "Could not unsubscribe from mailing list" : "Не удалось отписаться от списка рассылки",
+    "Go to latest message" : "Перейти к последнему сообщению",
+    "Go to newest message" : "Перейти к последнему сообщению",
+    "Thread Summary" : "Краткое описание темы",
+    "{name} Assistant" : "{name} Ассистент",
+    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Отключите сохранение корзины, оставив поле пустым или установив для него значение 0. Будут обрабатываться только письма, удаленные после включения сохранения корзины.",
     "Remove" : "Удалить",
     "No senders are trusted at the moment." : "Отсутствуют доверенные отправители.",
     "Could not remove trusted sender {sender}" : "Не удалось удалить доверенного отправителя {sender}",
@@ -364,9 +466,17 @@ OC.L10N.register(
     "Provisioning Configurations" : "Конфигурация развёртывания",
     "Add new config" : "Создать параметры конфигурации",
     "Provision all accounts" : "Настроить все учётные записи",
+    "Allow additional mail accounts" : "Разрешить дополнительные почтовые учетные записи",
+    "Allow additional Mail accounts from User Settings" : "Разрешить дополнительные учетные записи почты в настройках пользователя",
     "Anti Spam Service" : "Служба защиты от спама",
     "You can set up an anti spam service email address here." : "В этом поле возможно задать адрес эл. почты службы анти-спама.",
     "Any email that is marked as spam will be sent to the anti spam service." : "Все письма, отмеченные как спам, будут отправлены на адрес службы анти-спама.",
+    "Gmail integration" : "Интеграция с Gmail",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail позволяет пользователям получать доступ к своей электронной почте через IMAP. По соображениям безопасности этот доступ возможен только при подключении OAuth 2.0 или учетных записях Google, которые используют двухфакторную аутентификацию и пароли приложений.",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Вам необходимо зарегистрировать новый идентификатор клиента для «веб-приложения» в консоли Google Cloud. Добавьте URL-адрес {url} в качестве URI авторизованного перенаправления.",
+    "Microsoft integration" : "Интеграция с Microsoft",
+    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft позволяет пользователям получать доступ к своей электронной почте через IMAP. По соображениям безопасности этот доступ возможен только при подключении OAuth 2.0.",
+    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Вам необходимо зарегистрировать новое приложение на портале Microsoft Azure Active Directory. Добавьте URL-адрес {url} в качестве URI перенаправления.",
     "Successfully updated config for \"{domain}\"" : "Конфигурация домена «{domain}» обновлена",
     "Error saving config" : "Не удалось сохранить параметры конфигурации",
     "Saved config for \"{domain}\"" : "Конфигурация домена «{domain}» сохранена",
@@ -388,6 +498,14 @@ OC.L10N.register(
     "Error deleting anti spam reporting email" : "Ошибка при удалении анти-спам адреса отчёта электронной почты",
     "Client ID" : "ID клиента",
     "Client secret" : "Клиентский ключ ",
+    "Google integration configured" : "Интеграция с Google настроена",
+    "Could not configure Google integration" : "Не удалось настроить интеграцию с Google",
+    "Google integration unlinked" : "Интеграция с Google отключена",
+    "Could not unlink Google integration" : "Не удалось отменить интеграцию с Google",
+    "Microsoft integration configured" : "Интеграция Microsoft настроена",
+    "Could not configure Microsoft integration" : "Не удалось настроить интеграцию Microsoft",
+    "Microsoft integration unlinked" : "Интеграция с Microsoft отключена",
+    "Could not unlink Microsoft integration" : "Не удалось отменить интеграцию Microsoft",
     "Domain Match: {provisioningDomain}" : "Соответствует домену: {provisioningDomain}",
     "Email: {email}" : "Адрес: {email}",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на сервере {host}:{port} ({ssl} encryption)",
@@ -413,10 +531,24 @@ OC.L10N.register(
     "Unprovision & Delete Config" : "Отключить и удалить файл конфигурации",
     "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "*В поля %USERID% and %EMAIL% будут подставлены значения идентификаторов и адресов эл. почты пользователей",
     "With the settings above, the app will create account settings in the following way:" : "Для настраиваемых учётных записей будут применены следующие параметры:",
+    "S/MIME certificates" : "Сертификаты S/MIME",
+    "Certificate name" : "Название сертификата",
     "E-mail address" : "Адрес эл. почты",
     "Valid until" : "Дата истечения",
+    "Delete certificate" : "Удалить сертификат",
+    "No certificate imported yet" : "Сертификат еще не импортирован",
+    "Import certificate" : "Импортный сертификат",
+    "Import S/MIME certificate" : "Импортировать сертификат S/MIME",
+    "PKCS #12 Certificate" : "PKCS #12 Сертификат",
+    "PEM Certificate" : "PEM Сертификат",
     "Certificate" : "Сертификат",
+    "Private key (optional)" : "Закрытый ключ (необязательно)",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Закрытый ключ необходим только в том случае, если вы собираетесь отправлять подписанные и зашифрованные электронные письма с использованием этого сертификата.",
     "Submit" : "Отправить ответ",
+    "Failed to import the certificate. Please check the password." : "Не удалось импортировать сертификат. Пожалуйста, проверьте пароль.",
+    "Certificate imported successfully" : "Сертификат успешно импортирован",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Не удалось импортировать сертификат. Убедитесь, что закрытый ключ соответствует сертификату и не защищен парольной фразой.",
+    "Failed to import the certificate" : "Не удалось импортировать сертификат",
     "Keyboard shortcut" : "Комбинации клавиш",
     "Keyboard shortcuts" : "Комбинации клавиш",
     "Speed up your Mail experience with these quick shortcuts." : "Ускорьте работу с почтой использованием этих комбинаций клавиш.",
@@ -427,7 +559,9 @@ OC.L10N.register(
     "Toggle unread" : "Переключить отметку прочтения",
     "Archive" : "Переместить в архив",
     "Account connected" : "Аккаунт подключен",
+    "You can close this window" : "Вы можете закрыть это окно",
     "Connect your mail account" : "Настройка учётной записи электронной почты",
+    "To add a mail account, please contact your administrator." : "Чтобы добавить учетную запись почты, обратитесь к своему администратору.",
     "Tomorrow – {timeLocale}" : "Завтра – {timeLocale}",
     "Later today – {timeLocale}" : "Позднее сегодня – {timeLocale}",
     "Itinerary for {type} is not supported yet" : "Маршруты типа {type} пока не поддерживаются",
@@ -440,10 +574,15 @@ OC.L10N.register(
     "Junk" : "Спам",
     "Sent" : "Отправленные",
     "Trash" : "Корзина",
+    "Connect OAUTH2 account" : "Подключить учетную запись OAUTH2",
     "Error while sharing file" : "Ошибка сохранения файла",
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новое сообщение \nот {from}","%n новых сообщения \nот {from}","%n новых сообщений \nот {from}","%n новых сообщений \nот {from}"],
     "Nextcloud Mail" : "Почта Nextcloud",
+    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Сообщение уже находится в обработке. Если вы продолжите, все несохраненные изменения будут потеряны!",
+    "Discard changes" : "Отменить изменения",
+    "Discard unsaved changes" : "Отменить несохраненные изменения",
+    "Keep editing message" : "Продолжайте редактировать сообщение",
     "Attachments were not copied. Please add them manually." : "Вложения не скопированы, добавьте их вручную.",
     "Message sent" : "Сообщение отправлено",
     "Could not send message" : "Не удалось отправить сообщение",
