@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Vnorená správa %s",
     "Important mail" : "Dôležitý e-mail",
+    "No message found yet" : "Zatiaľ sa nenašla žiadna správa",
+    "Set up an account" : "Nastaviť si účet",
     "Unread mail" : "Neprečítaná pošta",
     "Important" : "Dôležité",
     "Work" : "Pracovné",
@@ -43,7 +45,7 @@ OC.L10N.register(
     "Sign in with Google" : "Prihlásiť pomocou Google",
     "Save" : "Uložiť",
     "Connect" : "Pripojiť",
-    "Looking up configuration" : "Vyhľadanie konfigurácie",
+    "Looking up configuration" : "Vyhľadávam konfiguráciu",
     "Checking mail host connectivity" : "Kontrola pripojenia k hostiteľovi elektronickej pošty",
     "Configuration discovery failed. Please use the manual settings" : "Zisťovanie konfigurácie zlyhalo. Použite manuálne nastavenia",
     "Password required" : "Vyžaduje sa heslo",
@@ -70,6 +72,7 @@ OC.L10N.register(
     "Trusted senders" : "Dôveryhodní odosielatelia",
     "Mail server" : "Poštový server",
     "Sieve filter server" : "Filtrovací server sieve",
+    "Mailbox search" : "Prehľadávanie pošty",
     "Update alias" : "Aktualizovať alternatívny názov",
     "Show update alias form" : "Zobraziť formulár pre aktualizáciu alternatívneho názvu",
     "Delete alias" : "Vymazať alternatívny názov",
@@ -83,6 +86,8 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Použiť Gravatar a favicon avatary",
     "Register as application for mail links" : "Zaregistrovať ako aplikáciu pre obsluhu e-mailových odkazov",
     "Show keyboard shortcuts" : "Zobraziť klávesové skratky",
+    "Newest" : "Najnovšie",
+    "Oldest" : "Najstaršie",
     "Looking for a way to encrypt your emails?" : "Hľadáte spôsob, ako šifrovať svoje e-maily?",
     "Install Mailvelope browser extension here" : "Tu si nainštalujte rozšírenie prehliadača Mailvelope",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Povoľte aplikácii zhromažďovať údaje o vašich interakciách. Na základe týchto údajov sa aplikácia prispôsobí vašim preferenciám. Dáta sa budú ukladať iba lokálne.",
@@ -92,7 +97,7 @@ OC.L10N.register(
     "From" : "Od",
     "Select account" : "Vybrať účet",
     "To" : "Pre",
-    "Contact or email address …" : "Kontakt alebo adresa e-mailu...",
+    "Contact or email address …" : "Kontakt alebo e-mailová adresa...",
     "Toggle recipients list mode" : "Prepnúť režim zoznamu príjemcov",
     "Cc" : "Kópia",
     "Bcc" : "Skrytá kópia",
@@ -120,7 +125,7 @@ OC.L10N.register(
     "Monday morning" : "Pondelok ráno",
     "Custom date and time" : "Vlastný dátum a čas",
     "Enter a date" : "Zadajte dátum",
-    "Add share link from {productName} Files" : "Pridať odkaz sprístupnenia zo Súborov {productName}",
+    "Add share link from {productName} Files" : "Pridať z {productName} Súborov odkaz so sprístupnením",
     "Send" : "Odoslať",
     "Message {id} could not be found" : "Správu {id} sa nepodarilo nájsť",
     "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Akékoľvek existujúce formátovanie (napríklad tučné, kurzíva, podčiarknuté alebo vložené obrázky) bude odstránené.",
@@ -132,8 +137,6 @@ OC.L10N.register(
     "_{count} attachment_::_{count} attachments_" : ["{count} príloha","{count} prílohy","{count} príloh","{count} prílohy"],
     "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Príloha prekračuje povolenú veľlkosť {size}. Daný súbor môžete sprístupniť pomocou odkazu.","Prílohy prekračujú povolenú veľkosť príloh {size}. Dané súbory môžete sprístupniť pomocou odkazu.","Prílohy prekračujú povolenú veľkosť príloh {size}. Dané súbory môžete sprístupniť pomocou odkazu.","Prílohy prekračujú povolenú veľkosť príloh {size}. Dané súbory môžete sprístupniť pomocou odkazu."],
     "Confirm" : "Potvrdiť",
-    "No message found yet" : "Zatiaľ sa nenašla žiadna správa",
-    "Set up an account" : "Nastaviť si účet",
     "Plain text" : "Obyčajný text",
     "Rich text" : "Formátovaný text",
     "No messages in this mailbox" : "V tejto poštovej schránke sa nenachádzajú žiadne správy",
@@ -151,20 +154,27 @@ OC.L10N.register(
     "Unselect" : "Zrušiť výber",
     "Select" : "Vybrať",
     "Edit tags" : "Upraviť štítky",
+    "Snooze" : "Odložiť",
+    "Unsnooze" : "Zrušiť odloženie",
     "Move thread" : "Presunúť konverzáciu",
     "Archive thread" : "Archivovať vlákno",
     "Delete thread" : "Vymazať konverzáciu",
     "More actions" : "Viac akcií",
     "Back" : "Späť",
+    "Set custom snooze" : "Nastaviť vlastné odloženie",
     "Edit as new message" : "Upraviť ako novú správu",
     "Create event" : "Vytvoriť udalosť",
     "Create task" : "Vytvoriť úlohu",
     "Download message" : "Stiahnuť správu",
     "Blind copy recipients only" : "Iba príjemcovia slepej kópie",
     "No subject" : "Žiadny predmet",
+    "Set reminder for tomorrow" : "Nastaviť pripomienku na zajtra",
+    "Set reminder for this weekend" : "Nastaviť pripomienku na tento víkend",
     "No trash mailbox configured" : "Nie je nakonfigurovaný žiadny priečinok pre Kôš",
     "Could not delete message" : "Správu sa nepodarilo odstrániť",
     "Could not archive message" : "Správu sa nepodarilo archivovať",
+    "Thread was snoozed" : "Vlákno bolo odložené",
+    "Thread was unsnoozed" : "Bolo zrušenie odloženie vlákna",
     "Forward" : "Preposlať",
     "Load more" : "Načítať viac",
     "_Mark {number} unread_::_Mark {number} unread_" : ["Označiť {number} správu ako neprečítanú","Označiť {number} správy ako neprečítané","Označiť {number} správ ako neprečítané","Označiť {number} správ ako neprečítané"],
@@ -204,7 +214,7 @@ OC.L10N.register(
     "Loading messages …" : "Načítavam správy ...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexovanie správ. U väčších poštových schránok to môže chvíľu trvať.",
     "Choose target mailbox" : "Vyberte cieľovú schránku",
-    "No more submailboxes in here" : "Žadne ďaľšie podschránky",
+    "No more submailboxes in here" : "Žadne ďalšie podschránky",
     "Choose" : "Vybrať",
     "Important info" : "Dôležité informácie",
     "Other" : "Iné",
@@ -220,13 +230,15 @@ OC.L10N.register(
     "Forward message as attachment" : "Preposlať správu ako prílohu",
     "View source" : "Zobraziť zdrojový kód",
     "Download thread data for debugging" : "Prevziať dáta vlákna pre účely ladenia",
-    "Message source" : "Zdrojový kód správy",
+    "Message was snoozed" : "Správa bola odložené",
+    "Message was unsnoozed" : "Bolo zrušené odloženie správy",
     "Message body" : "Telo správy",
     "Import into calendar" : "Importovať do kalendára",
     "Download attachment" : "Stiahnuť prílohu",
     "Save to Files" : "Uložiť do Súborov",
     "Unnamed" : "nepomenovaný",
     "Embedded message" : "Vnorená správa",
+    "Next week – {timeLocale}" : "Budúci týždeň – {timeLocale}",
     "Choose a folder to store the attachment in" : "Vyberte priečinok pre uloženie prílohy",
     "View fewer attachments" : "Zobraziť menej príloh",
     "Save all to Files" : "Uložiť všetko do Súborov",
@@ -296,6 +308,7 @@ OC.L10N.register(
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "V kolónkach Pre resp. Kópia sa nachádza príliš veľa príjemcov. Zvážte použitie kolónky Skrytej kópie, pomocou ktorej skryjete e-mailové adresy všetkých príjemcov.",
     "Message discarded" : "Správa bola zrušená",
     "Could not discard message" : "Správu sa nepodarilo zahodiť",
+    "Welcome to {cloudName} Mail" : "Vitajte v {cloudName} pošte",
     "Autoresponder off" : "Automatická odpoveď vypnutá",
     "Autoresponder on" : "Automatická odpoveď zapnutá",
     "First day" : "Prvý deň",
@@ -317,9 +330,15 @@ OC.L10N.register(
     "Search in mailbox" : "Vyhľadať v schránke",
     "Close" : "Zatvoriť",
     "Search parameters" : "Parametre vyhľadávania",
-    "Search term" : "Hľadaný výraz",
+    "Search subject" : "Hľadať v predmete",
+    "Body" : "Telo",
+    "Search body" : "Hľadať v texte",
     "Pick a start date" : "Vyberte počiatočný dátum",
     "Pick an end date" : "Vyberte konečný dátum",
+    "Select senders" : "Vyberte odosielateľov",
+    "Select recipients" : "Vyberte príjemcov",
+    "Select CC recipients" : "Vyberte príjemcov v CC",
+    "Select BCC recipients" : "Vyberte príjemcov v BCC",
     "Tags" : "Štítky",
     "Select tags" : "Vyberte štítky",
     "Marked as" : "Označené ako",
@@ -327,6 +346,7 @@ OC.L10N.register(
     "Clear" : "Vyčistiť",
     "Search" : "Hľadať",
     "Date" : "Dátum",
+    "Enable mail body search" : "Povoliť prehľadávanie textu e-mailu",
     "Disabled" : "Vypnuté",
     "Enabled" : "Zapnuté",
     "Sieve Host" : "Hostiteľ Sieve",
@@ -339,19 +359,21 @@ OC.L10N.register(
     "Sieve Password" : "Heslo Sieve",
     "Save sieve settings" : "Uložiť nastavenia Sieve",
     "Save sieve script" : "Uložiť skript Sieve",
+    "This weekend – {timeLocale}" : "Tento víkend – {timeLocale}",
     "Signature …" : "Podpis…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Váš podpis je väčší ako 2 MB. Môže to ovplyvniť výkon vášho editora.",
     "Save signature" : "Uložiť podpis",
     "Place signature above quoted text" : "Umiestniť podpis nad citovaný text",
-    "Add default tags" : "Pridať predvolené štítky",
-    "Rename tag" : "Premenovať štítok",
+    "Edit name or color" : "Upraviť názov farby",
+    "Delete tag" : "Zmazať štítok",
     "Saving new tag name …" : "Ukladám nový názov štítku ...",
+    "An error occurred, unable to rename the tag." : "Vyskytla sa chyba, nie je možné premenovať štítok.",
+    "Add default tags" : "Pridať predvolené štítky",
     "Add tag" : "Pridať štítok",
     "Saving tag …" : "Ukladám štítok ...",
     "Tag name is a hidden system tag" : "Názov štítku už existuje ako skrytý systémový štítok",
     "Tag already exists" : "Štítok už existuje",
     "An error occurred, unable to create the tag." : "Vyskytla sa chyba, nie je možné vytvoriť štítok.",
-    "An error occurred, unable to rename the tag." : "Vyskytla sa chyba, nie je možné premenovať štítok.",
     "Loading thread" : "Načítavam vlákno",
     "Not found" : "Nenájdené",
     "Could not load your message thread" : "Nepodarilo sa načítať vlákno vašich správ",
@@ -363,6 +385,7 @@ OC.L10N.register(
     "Mark as read" : "Označiť ako prečítané",
     "Archive message" : "Archivovať správu",
     "Delete message" : "Zmazať správu",
+    "Message source" : "Zdrojový kód správy",
     "Remove" : "Odobrať",
     "No senders are trusted at the moment." : "Momentálne nie sú dôveryhodní žiadni odosielatelia.",
     "Could not remove trusted sender {sender}" : "Nepodarilo sa odstrániť dôveryhodného odosielateľa {sender}",
@@ -458,8 +481,10 @@ OC.L10N.register(
     "Toggle unread" : "Prepnúť neprečítané",
     "Archive" : "Archivovať",
     "Account connected" : "Účet pripojený",
-    "Connect your mail account" : "Pripojiť Váš mailový účet",
+    "Connect your mail account" : "Pripojte si váš e-mailový účet",
     "To add a mail account, please contact your administrator." : "Pre pridanie ďalšieho e-mailového účtu kontaktujte administrátora.",
+    "Tomorrow – {timeLocale}" : "Zajtra – {timeLocale}",
+    "Later today – {timeLocale}" : "Neskôr dnes - {timeLocale}",
     "Itinerary for {type} is not supported yet" : "Itinerár pre {type} zatiaľ nie je podporovaný",
     "All" : "Všetko",
     "Drafts" : "Koncepty",
