@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Embedded message %s" : "Вбудоване повідомлення %s",
     "Important mail" : "Важлива пошта",
+    "No message found yet" : "Відсутні повідомлення",
+    "Set up an account" : "Створити обліковий запис",
     "Unread mail" : "Непрочитана пошта",
     "Important" : "Важливі",
     "Work" : "Робочий",
@@ -119,7 +121,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Виберіть файл, яким ви поділитеся через посилання",
     "_{count} attachment_::_{count} attachments_" : ["{count} долучений файл","{count} долучені файли","{count} долучених файлів","{count} долучених файлів"],
     "Confirm" : "Підтвердити",
-    "Set up an account" : "Створити обліковий запис",
     "Plain text" : "Простий текст",
     "Rich text" : "Текст з форматуванням",
     "No messages" : "Відсутні повідомлення",
@@ -140,6 +141,10 @@ OC.L10N.register(
     "Create task" : "Створити завдання",
     "Download message" : "Завантажити повідомлення",
     "Blind copy recipients only" : "Лише отримувачі у прихованій копії",
+    "Set reminder for later today" : "Встановити нагадування на сьогодні пізніше",
+    "Set reminder for tomorrow" : "Встановити нагадування на завтра",
+    "Set reminder for this weekend" : "Встановити нагадування на ці вихідні",
+    "Set reminder for next week" : "Встановити нагадування на наступний тиждень",
     "Forward" : "Переслати",
     "Load more" : "Більше",
     "Report this bug" : "Повідомити про помилку",
@@ -158,7 +163,6 @@ OC.L10N.register(
     "Reply" : "Відповісти",
     "Reply to sender only" : "Відповісти лише відправникові",
     "View source" : "Джерело",
-    "Message source" : "Джерело повідомлення",
     "Import into calendar" : "Імпортувати до календаря",
     "Download attachment" : "Звантажити вкладення",
     "Save to Files" : "Зберегти до Файлів",
@@ -174,6 +178,7 @@ OC.L10N.register(
     "Move" : "Перемістити",
     "Quota" : "Обмеження",
     "Saving" : "Збереження",
+    "Move up" : "Пересунуту догори",
     "Move down" : "Пересунути вниз",
     "Remove account" : "Вилучити обліковий запис",
     "Loading …" : "Завантаження...",
@@ -200,6 +205,7 @@ OC.L10N.register(
     "Copy to clipboard" : "Копіювати до буферу обміну ",
     "Add" : "Додати",
     "Close" : "Закрити",
+    "Body" : "Тіло",
     "Tags" : "Мітки",
     "Select tags" : "Виберіть мітки",
     "Clear" : "Очистити",
@@ -215,6 +221,7 @@ OC.L10N.register(
     "Not found" : "Не знайдено",
     "Mark as unread" : "Позначити не прочитаним",
     "Mark as read" : "Позначити прочитаним",
+    "Message source" : "Джерело повідомлення",
     "Remove" : "Вилучити",
     "(organizer)" : "(організатор)",
     "Untitled event" : "Подія без назви",
