@@ -47,8 +47,8 @@ class DiagnoseAccount extends Command {
 	private LoggerInterface $logger;
 
 	public function __construct(AccountService $service,
-								IMAPClientFactory $clientFactory,
-								LoggerInterface $logger) {
+		IMAPClientFactory $clientFactory,
+		LoggerInterface $logger) {
 		parent::__construct();
 
 		$this->accountService = $service;
@@ -102,7 +102,7 @@ class DiagnoseAccount extends Command {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	private function printCapabilitiesStats(OutputInterface $output,
-											Horde_Imap_Client_Socket $imapClient): void {
+		Horde_Imap_Client_Socket $imapClient): void {
 		$output->writeln("IMAP capabilities:");
 		// Once logged in more capabilities are advertised
 		$imapClient->login();
@@ -126,11 +126,11 @@ class DiagnoseAccount extends Command {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	protected function printMailboxesMessagesStats(OutputInterface $output,
-												   Horde_Imap_Client_Socket $imapClient): void {
+		Horde_Imap_Client_Socket $imapClient): void {
 		$mailboxes = $imapClient->listMailboxes('*', Horde_Imap_Client::MBOX_ALL, [
 			'flat' => true,
 		]);
-		$messages = array_reduce($mailboxes, function (int $c, Horde_Imap_Client_Mailbox $mb) use ($imapClient) {
+		$messages = array_reduce($mailboxes, static function (int $c, Horde_Imap_Client_Mailbox $mb) use ($imapClient) {
 			$status = $imapClient->status($mb, Horde_Imap_Client::STATUS_MESSAGES);
 			return $c + $status['messages'];
 		}, 0);
