@@ -30,7 +30,7 @@ use OCA\Mail\Db\TrustedSender;
 interface ITrustedSenderService {
 	public function isTrusted(string $uid, string $email): bool;
 
-	public function trust(string $uid, string $email, ?bool $trust = true);
+	public function trust(string $uid, string $email, string $type, ?bool $trust = true);
 
 	/**
 	 * @param string $uid
