@@ -245,7 +245,8 @@ class AccountsController extends Controller {
 		int $snoozeMailboxId = null,
 		bool $signatureAboveQuote = null,
 		int $trashRetentionDays = null,
-		int $junkMailboxId = null): JSONResponse {
+		int $junkMailboxId = null,
+		bool $searchBody = null): JSONResponse {
 		$account = $this->accountService->find($this->currentUserId, $id);
 
 		$dbAccount = $account->getMailAccount();
@@ -290,6 +291,9 @@ class AccountsController extends Controller {
 			$this->mailManager->getMailbox($this->currentUserId, $junkMailboxId);
 			$dbAccount->setJunkMailboxId($junkMailboxId);
 		}
+		if($searchBody !== null) {
+			$dbAccount->setSearchBody($searchBody);
+		}
 		return new JSONResponse(
 			$this->accountService->save($dbAccount)
 		);
@@ -457,6 +461,7 @@ class AccountsController extends Controller {
 				$draftsMailbox,
 				Horde_Imap_Client::SYNC_NEWMSGSUIDS,
 				[],
+				null,
 				false
 			);
 			return new JSONResponse([
@@ -501,4 +506,19 @@ class AccountsController extends Controller {
 		$this->accountService->update($account);
 		return MailJsonResponse::success();
 	}
+
+	/**
+	 * @NoAdminRequired
+	 *
+	 * @param int $id Account id
+	 * @return JSONResponse
+	 *
+	 * @throws ClientException
+	 */
+	public function testAccountConnection(int $id) {
+		return new JSONResponse([
+			'data' => $this->accountService->testAccountConnection($this->currentUserId, $id),
+		]);
+	}
+
 }
