@@ -61,19 +61,19 @@ class AutoConfigController extends Controller {
 	 * @param string $email
 	 *
 	 * @NoAdminRequired
-	 * @UserRateThrottle(limit: 5, period: 60)
+	 * @UserRateThrottle(limit=5, period=60)
 	 *
 	 * @return JsonResponse
 	 */
 	#[TrapError]
 	#[UserRateLimit(limit: 5, period: 60)]
-	public function queryIspdb(string $email): JsonResponse {
+	public function queryIspdb(string $host, string $email): JsonResponse {
 		$rfc822Address = new Horde_Mail_Rfc822_Address($email);
-		if (!$rfc822Address->valid || !$this->hostValidator->isValid($rfc822Address->host)) {
+		if (!$rfc822Address->valid || !$this->hostValidator->isValid($host)) {
 			return JsonResponse::fail('Invalid email address', Http::STATUS_UNPROCESSABLE_ENTITY)
 				->cacheFor(60 * 60, false, true);
 		}
-		$config = $this->ispDb->query($rfc822Address->host, $rfc822Address);
+		$config = $this->ispDb->query($host, $rfc822Address);
 		return JsonResponse::success($config)->cacheFor(5 * 60, false, true);
 	}
 
@@ -81,7 +81,7 @@ class AutoConfigController extends Controller {
 	 * @param string $email
 	 *
 	 * @NoAdminRequired
-	 * @UserRateThrottle(limit: 5, period: 60)
+	 * @UserRateThrottle(limit=5, period=60)
 	 *
 	 * @return JsonResponse
 	 */
@@ -103,12 +103,12 @@ class AutoConfigController extends Controller {
 	 * @param int $port
 	 *
 	 * @NoAdminRequired
-	 * @UserRateThrottle(limit: 10, period: 60)
+	 * @UserRateThrottle(limit=30, period=60)
 	 *
 	 * @return JsonResponse
 	 */
 	#[TrapError]
-	#[UserRateLimit(limit: 10, period: 60)]
+	#[UserRateLimit(limit: 30, period: 60)]
 	public function testConnectivity(string $host, int $port): JsonResponse {
 		if (!in_array($port, [143, 993, 465, 587])) {
 			return JsonResponse::fail('Port not allowed');
