@@ -51,7 +51,11 @@ use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
 use OCP\IRequest;
 use OCP\IURLGenerator;
+use OCP\IUserManager;
 use OCP\IUserSession;
+use OCP\User\IAvailabilityCoordinator;
+use Psr\Container\ContainerExceptionInterface;
+use Psr\Container\ContainerInterface;
 use Psr\Log\LoggerInterface;
 use Throwable;
 use function class_exists;
@@ -75,6 +79,8 @@ class PageController extends Controller {
 	private ICredentialstore $credentialStore;
 	private SmimeService $smimeService;
 	private AiIntegrationsService $aiIntegrationsService;
+	private IUserManager $userManager;
+	private ?IAvailabilityCoordinator $availabilityCoordinator;
 
 	public function __construct(string $appName,
 		IRequest $request,
@@ -93,7 +99,9 @@ class PageController extends Controller {
 		IEventDispatcher $dispatcher,
 		ICredentialStore $credentialStore,
 		SmimeService     $smimeService,
-		AiIntegrationsService $aiIntegrationsService) {
+		AiIntegrationsService $aiIntegrationsService,
+		IUserManager $userManager,
+		ContainerInterface $container) {
 		parent::__construct($appName, $request);
 
 		$this->urlGenerator = $urlGenerator;
@@ -112,6 +120,13 @@ class PageController extends Controller {
 		$this->credentialStore = $credentialStore;
 		$this->smimeService = $smimeService;
 		$this->aiIntegrationsService = $aiIntegrationsService;
+		$this->userManager = $userManager;
+
+		try {
+			$this->availabilityCoordinator = $container->get(IAvailabilityCoordinator::class);
+		} catch (ContainerExceptionInterface $e) {
+			$this->availabilityCoordinator = null;
+		}
 	}
 
 	/**
@@ -166,6 +181,11 @@ class PageController extends Controller {
 			$this->tagMapper->getAllTagsForUser($this->currentUserId)
 		);
 
+		$this->initialStateService->provideInitialState(
+			'sort-order',
+			$this->preferences->getPreference($this->currentUserId, 'sort-order', 'newest')
+		);
+
 		try {
 			$password = $this->credentialStore->getLoginCredentials()->getPassword();
 			$passwordIsUnavailable = $password === null || $password === '';
@@ -185,12 +205,13 @@ class PageController extends Controller {
 				'external-avatars' => $this->preferences->getPreference($this->currentUserId, 'external-avatars', 'true'),
 				'reply-mode' => $this->preferences->getPreference($this->currentUserId, 'reply-mode', 'top'),
 				'collect-data' => $this->preferences->getPreference($this->currentUserId, 'collect-data', 'true'),
+				'search-priority-body' => $this->preferences->getPreference($this->currentUserId, 'search-priority-body', 'false'),
 				'start-mailbox-id' => $this->preferences->getPreference($this->currentUserId, 'start-mailbox-id'),
 				'tag-classified-messages' => $this->preferences->getPreference($this->currentUserId, 'tag-classified-messages', 'true'),
 			]);
 		$this->initialStateService->provideInitialState(
 			'prefill_displayName',
-			$user->getDisplayName()
+			$this->userManager->getDisplayName($this->currentUserId),
 		);
 		$this->initialStateService->provideInitialState(
 			'prefill_email',
@@ -267,6 +288,13 @@ class PageController extends Controller {
 			),
 		);
 
+		if ($this->availabilityCoordinator !== null) {
+			$this->initialStateService->provideInitialState(
+				'enable-system-out-of-office',
+				$this->availabilityCoordinator->isEnabled(),
+			);
+		}
+
 		$csp = new ContentSecurityPolicy();
 		$csp->addAllowedFrameDomain('\'self\'');
 		$response->setContentSecurityPolicy($csp);
