@@ -27,7 +27,6 @@ declare(strict_types=1);
 namespace OCA\Mail\Dashboard;
 
 class ImportantMailWidget extends MailWidget {
-
 	/**
 	 * @inheritDoc
 	 */
@@ -41,4 +40,11 @@ class ImportantMailWidget extends MailWidget {
 	public function getTitle(): string {
 		return $this->l10n->t('Important mail');
 	}
+
+	/**
+	 * @inheritDoc
+	 */
+	public function getSearchFilter(): string {
+		return 'is:important';
+	}
 }
