@@ -34,7 +34,6 @@ use Horde_Imap_Client_Exception_NoSupportExtension;
 use Horde_Imap_Client_Fetch_Query;
 use Horde_Imap_Client_Ids;
 use Horde_ListHeaders;
-use Horde_ListHeaders_Base;
 use Horde_Mime_Exception;
 use Horde_Mime_Headers;
 use Horde_Mime_Part;
@@ -314,8 +313,11 @@ class ImapMessageFetcher {
 			}
 		}
 
+		$isAttachment = ($p->isAttachment() || $p->getType() === 'message/rfc822') &&
+			!in_array($p->getType(), ['application/pgp-signature', 'application/pkcs7-signature', 'application/x-pkcs7-signature']);
+
 		// Regular attachments
-		if ($p->isAttachment() || $p->getType() === 'message/rfc822') {
+		if ($isAttachment) {
 			$this->attachments[] = [
 				'id' => $p->getMimeId(),
 				'messageId' => $this->uid,
@@ -523,8 +525,11 @@ class ImapMessageFetcher {
 		$listUnsubscribeHeader = $parsedHeaders->getHeader('list-unsubscribe');
 		if ($listUnsubscribeHeader !== null) {
 			$listHeaders = new Horde_ListHeaders();
-			/** @var Horde_ListHeaders_Base[] $headers */
 			$headers = $listHeaders->parse($listUnsubscribeHeader->name, $listUnsubscribeHeader->value_single);
+			if (!$headers) {
+				// Unable to parse headers
+				return;
+			}
 			foreach ($headers as $header) {
 				if (str_starts_with($header->url, 'http')) {
 					$this->unsubscribeUrl = $header->url;
