@@ -67,8 +67,8 @@ class MessageMapper {
 	private ImapMessageFetcherFactory $imapMessageFactory;
 
 	public function __construct(LoggerInterface           $logger,
-								SmimeService              $smimeService,
-								ImapMessageFetcherFactory $imapMessageFactory) {
+		SmimeService              $smimeService,
+		ImapMessageFetcherFactory $imapMessageFactory) {
 		$this->logger = $logger;
 		$this->smimeService = $smimeService;
 		$this->imapMessageFactory = $imapMessageFactory;
@@ -80,10 +80,10 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function find(Horde_Imap_Client_Base $client,
-						 string $mailbox,
-						 int $id,
-						 string $userId,
-						 bool $loadBody = false): IMAPMessage {
+		string $mailbox,
+		int $id,
+		string $userId,
+		bool $loadBody = false): IMAPMessage {
 		$result = $this->findByIds($client, $mailbox, new Horde_Imap_Client_Ids([$id]), $userId, $loadBody);
 
 		if (count($result) === 0) {
@@ -105,12 +105,12 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function findAll(Horde_Imap_Client_Socket $client,
-							string $mailbox,
-							int $maxResults,
-							int $highestKnownUid,
-							LoggerInterface $logger,
-							PerformanceLoggerTask $perf,
-							string $userId): array {
+		string $mailbox,
+		int $maxResults,
+		int $highestKnownUid,
+		LoggerInterface $logger,
+		PerformanceLoggerTask $perf,
+		string $userId): array {
 		/**
 		 * To prevent memory exhaustion, we don't want to just ask for a list of
 		 * all UIDs and limit them client-side. Instead, we can (hopefully
@@ -133,11 +133,8 @@ class MessageMapper {
 			]
 		);
 		$perf->step('mailbox meta search');
-		/** @var int $min */
 		$min = (int) $metaResults['min'];
-		/** @var int $max */
 		$max = (int) $metaResults['max'];
-		/** @var int $total */
 		$total = (int) $metaResults['count'];
 
 		if ($total === 0) {
@@ -254,10 +251,10 @@ class MessageMapper {
 	 * @throws ServiceException
 	 */
 	public function findByIds(Horde_Imap_Client_Base $client,
-							  string $mailbox,
-							  $ids,
-							  string $userId,
-							  bool $loadBody = false): array {
+		string $mailbox,
+		$ids,
+		string $userId,
+		bool $loadBody = false): array {
 		$query = new Horde_Imap_Client_Fetch_Query();
 		$query->envelope();
 		$query->flags();
@@ -320,17 +317,21 @@ class MessageMapper {
 	 * @param string $sourceFolderId
 	 * @param int $messageId
 	 * @param string $destFolderId
+	 * @return int the new UID
 	 */
 	public function move(Horde_Imap_Client_Base $client,
-						 string $sourceFolderId,
-						 int $messageId,
-						 string $destFolderId): void {
+		string $sourceFolderId,
+		int $messageId,
+		string $destFolderId): int {
 		try {
-			$client->copy($sourceFolderId, $destFolderId,
+			$mapping = $client->copy($sourceFolderId, $destFolderId,
 				[
 					'ids' => new Horde_Imap_Client_Ids($messageId),
 					'move' => true,
+					'force_map' => true,
 				]);
+
+			return $mapping[$messageId];
 		} catch (Horde_Imap_Client_Exception $e) {
 			$this->logger->debug($e->getMessage(),
 				[
@@ -347,7 +348,7 @@ class MessageMapper {
 	}
 
 	public function markAllRead(Horde_Imap_Client_Base $client,
-								string $mailbox): void {
+		string $mailbox): void {
 		$client->store($mailbox, [
 			'add' => [
 				Horde_Imap_Client::FLAG_SEEN,
@@ -359,8 +360,8 @@ class MessageMapper {
 	 * @throws ServiceException
 	 */
 	public function expunge(Horde_Imap_Client_Base $client,
-							string $mailbox,
-							int $id): void {
+		string $mailbox,
+		int $id): void {
 		try {
 			$client->expunge(
 				$mailbox,
@@ -385,9 +386,9 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function save(Horde_Imap_Client_Socket $client,
-						 Mailbox $mailbox,
-						 Horde_Mime_Mail $mail,
-						 array $flags = []): int {
+		Mailbox $mailbox,
+		Horde_Mime_Mail $mail,
+		array $flags = []): int {
 		$flags = array_merge([
 			Horde_Imap_Client::FLAG_SEEN,
 		], $flags);
@@ -409,9 +410,9 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function addFlag(Horde_Imap_Client_Socket $client,
-							Mailbox $mailbox,
-							array $uids,
-							string $flag): void {
+		Mailbox $mailbox,
+		array $uids,
+		string $flag): void {
 		$client->store(
 			$mailbox->getName(),
 			[
@@ -425,9 +426,9 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function removeFlag(Horde_Imap_Client_Socket $client,
-							   Mailbox $mailbox,
-							   array $uids,
-							   string $flag): void {
+		Mailbox $mailbox,
+		array $uids,
+		string $flag): void {
 		$client->store(
 			$mailbox->getName(),
 			[
@@ -446,8 +447,8 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function getFlagged(Horde_Imap_Client_Socket $client,
-							   Mailbox $mailbox,
-							   string $flag): array {
+		Mailbox $mailbox,
+		string $flag): array {
 		$query = new Horde_Imap_Client_Search_Query();
 		$query->flag($flag, true);
 		$messages = $client->search($mailbox->getName(), $query);
@@ -465,10 +466,10 @@ class MessageMapper {
 	 * @throws ServiceException
 	 */
 	public function getFullText(Horde_Imap_Client_Socket $client,
-								string $mailbox,
-								int $uid,
-								string $userId,
-								bool $decrypt = true): ?string {
+		string $mailbox,
+		int $uid,
+		string $userId,
+		bool $decrypt = true): ?string {
 		$query = new Horde_Imap_Client_Fetch_Query();
 
 		if ($decrypt) {
@@ -514,9 +515,9 @@ class MessageMapper {
 	 * @throws ServiceException
 	 */
 	public function getHtmlBody(Horde_Imap_Client_Socket $client,
-								string                   $mailbox,
-								int                      $uid,
-								string                   $userId): ?string {
+		string                   $mailbox,
+		int                      $uid,
+		string                   $userId): ?string {
 		$messageQuery = new Horde_Imap_Client_Fetch_Query();
 		$messageQuery->envelope();
 		$messageQuery->structure();
@@ -592,10 +593,10 @@ class MessageMapper {
 	 * @throws ServiceException
 	 */
 	public function getRawAttachments(Horde_Imap_Client_Socket $client,
-									  string $mailbox,
-									  int $uid,
-									  string $userId,
-									  ?array $attachmentIds = []): array {
+		string $mailbox,
+		int $uid,
+		string $userId,
+		?array $attachmentIds = []): array {
 		$attachments = $this->getAttachments($client, $mailbox, $uid, $userId, $attachmentIds);
 		return array_map(static function (Attachment $attachment) {
 			return $attachment->getContent();
@@ -619,10 +620,10 @@ class MessageMapper {
 	 * @throws Horde_Mime_Exception
 	 */
 	public function getAttachments(Horde_Imap_Client_Socket $client,
-								   string $mailbox,
-								   int $uid,
-								   string $userId,
-								   ?array $attachmentIds = []): array {
+		string $mailbox,
+		int $uid,
+		string $userId,
+		?array $attachmentIds = []): array {
 		$uids = new Horde_Imap_Client_Ids([$uid]);
 
 		$messageQuery = new Horde_Imap_Client_Fetch_Query();
@@ -682,13 +683,36 @@ class MessageMapper {
 				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
 					$part->setTransferEncoding($enc);
 				}
-				$part->setContents($stream, [
-					'usestream' => true,
-				]);
-				fclose($stream);
-			}
 
-			$attachments[] = Attachment::fromMimePart($part);
+				/*
+				 * usestream depends on transfer encoding
+				 *
+				 * Case 1: base64 encoded file
+				 * Base64 stream is copied to a new stream and decoded using a convert.base64-decode stream filter.
+				 *
+				 * Case 2: text file (no transfer encoding)
+				 * Existing stream is reused in Horde_Mime_Part.
+				 *
+				 * To handle both cases:
+				 *
+				 * 1) Horde_Mime_Part.clearContents to close the internal stream (Horde_Mime_Part._contents)
+				 * 2) If $stream is still open, the data was transfer encoded, close it.
+				 *
+				 * Attachment.fromMimePart uses Horde_Mime_Part.getContents and Horde_Mime_Part.getBytes
+				 * and therefore needs an open input stream.
+				 */
+				$part->setContents($stream, [
+					'usestream' => true
+				]);
+				$attachments[] = Attachment::fromMimePart($part);
+				$part->clearContents();
+				if (is_resource($stream)) {
+					fclose($stream);
+				}
+			} else {
+				$attachments[] = Attachment::fromMimePart($part);
+				$part->clearContents();
+			}
 		}
 		return $attachments;
 	}
@@ -707,10 +731,10 @@ class MessageMapper {
 	 * @throws Horde_Mime_Exception
 	 */
 	public function getAttachment(Horde_Imap_Client_Base $client,
-								  string $mailbox,
-								  int $messageUid,
-								  string $attachmentId,
-								  string $userId): Attachment {
+		string $mailbox,
+		int $messageUid,
+		string $attachmentId,
+		string $userId): Attachment {
 		// TODO: compare logic and merge with getAttachments()
 
 		$query = new Horde_Imap_Client_Fetch_Query();
@@ -741,7 +765,6 @@ class MessageMapper {
 			if (!isset($result[$messageUid])) {
 				throw new DoesNotExistException('Unable to load the attachment.');
 			}
-			/** @var Horde_Imap_Client_Data_Fetch $fetch */
 			$fullTextResult = $result[$messageUid];
 
 			$decryptedText = $this->smimeService
@@ -837,8 +860,8 @@ class MessageMapper {
 	 * @throws Horde_Imap_Client_Exception
 	 */
 	public function getBodyStructureData(Horde_Imap_Client_Socket $client,
-										 string $mailbox,
-										 array $uids): array {
+		string $mailbox,
+		array $uids): array {
 		$structureQuery = new Horde_Imap_Client_Fetch_Query();
 		$structureQuery->structure();
 		$structureQuery->headerText([
@@ -909,7 +932,26 @@ class MessageMapper {
 			if ($part === null) {
 				return new MessageStructureData($hasAttachments, $text, $isImipMessage, $isEncrypted);
 			}
+
+
+			$htmlBody = ($htmlBodyId !== null) ? $part->getBodyPart($htmlBodyId) : null;
+			if (!empty($htmlBody)) {
+				$mimeHeaders = $part->getMimeHeader($htmlBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
+				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
+					$structure->setTransferEncoding($enc);
+					$structure->setContents($htmlBody);
+					$htmlBody = $structure->getContents();
+				}
+				$html = new Html2Text($htmlBody, array('do_links' => 'none','alt_image' => 'hide'));
+				return new MessageStructureData(
+					$hasAttachments,
+					trim($html->getText()),
+					$isImipMessage,
+					$isEncrypted,
+				);
+			}
 			$textBody = $part->getBodyPart($textBodyId);
+
 			if (!empty($textBody)) {
 				$mimeHeaders = $part->getMimeHeader($textBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
 				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
@@ -924,24 +966,6 @@ class MessageMapper {
 					$isEncrypted,
 				);
 			}
-
-			$htmlBody = ($htmlBodyId !== null) ? $part->getBodyPart($htmlBodyId) : null;
-			if (!empty($htmlBody)) {
-				$mimeHeaders = $part->getMimeHeader($htmlBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
-				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
-					$structure->setTransferEncoding($enc);
-					$structure->setContents($htmlBody);
-					$htmlBody = $structure->getContents();
-				}
-				// TODO:  add 'alt_image' => 'hide' once it's added to the Html2Text package
-				$html = new Html2Text($htmlBody, array('do_links' => 'none',));
-				return new MessageStructureData(
-					$hasAttachments,
-					trim($html->getText()),
-					$isImipMessage,
-					$isEncrypted,
-				);
-			}
 			return new MessageStructureData($hasAttachments, $text, $isImipMessage, $isEncrypted);
 		}, iterator_to_array($structures->getIterator()));
 	}
