@@ -73,9 +73,9 @@ class Provider {
 	 */
 	private function convertMailQueryToHordeQuery(SearchQuery $searchQuery): Horde_Imap_Client_Search_Query {
 		return array_reduce(
-			$searchQuery->getTextTokens(),
+			$searchQuery->getBodies(),
 			static function (Horde_Imap_Client_Search_Query $query, string $textToken) {
-				$query->text($textToken, false);
+				$query->text($textToken, true);
 				return $query;
 			},
 			new Horde_Imap_Client_Search_Query()
