@@ -24,6 +24,6 @@ class Version1030Date20200228105714 extends SimpleMigrationStep {
 		$update = $this->connection->getQueryBuilder();
 		$update->update('mail_accounts')
 			->set('last_mailbox_sync', $update->createNamedParameter(0));
-		$update->execute();
+		$update->executeStatement();
 	}
 }
