@@ -6,6 +6,7 @@ namespace OCA\Mail\Migration;
 
 use Closure;
 use OCP\DB\ISchemaWrapper;
+use OCP\DB\Types;
 use OCP\Migration\IOutput;
 use OCP\Migration\SimpleMigrationStep;
 
@@ -21,7 +22,7 @@ class Version1100Date20210317164707 extends SimpleMigrationStep {
 		$schema = $schemaClosure();
 
 		$table = $schema->getTable('mail_aliases');
-		$table->addColumn('signature', 'text', [
+		$table->addColumn('signature', Types::TEXT, [
 			'notnull' => false,
 			'length' => 1024,
 			'default' => '',
