@@ -43,9 +43,9 @@ class ContactsIntegration {
 	private $config;
 
 	public function __construct(IManager $contactsManager,
-								IGroupManager $groupManager,
-								IUserManager $userManager,
-								IConfig $config) {
+		IGroupManager $groupManager,
+		IUserManager $userManager,
+		IConfig $config) {
 		$this->contactsManager = $contactsManager;
 		$this->groupManager = $groupManager;
 		$this->userManager = $userManager;
@@ -211,13 +211,8 @@ class ContactsIntegration {
 
 	/**
 	 * Adds a new contact with the specified email to an addressbook
-	 *
-	 * @param string $uid
-	 * @param string $mailAddr
-	 * @param string $addressbook
-	 * @return array|null
 	 */
-	public function newContact(string $name, string $mailAddr, string $type = 'HOME', string $addressbook = null) {
+	public function newContact(string $name, string $mailAddr, string $type = 'HOME', string $addressbook = null): ?array {
 		if (!$this->contactsManager->isEnabled()) {
 			return null;
 		}
@@ -275,11 +270,8 @@ class ContactsIntegration {
 
 	/**
 	 * Extracts all Contacts with the specified name
-	 *
-	 * @param string $mailAddr
-	 * @return array
 	 */
-	public function getContactsWithName(string $name) {
+	public function getContactsWithName(string $name): array {
 		return $this->doSearch($name, ['FN'], false);
 	}
 }
