@@ -71,7 +71,7 @@ class Html {
 		$linker = new UrlLinker([
 			'allowFtpAddresses' => true,
 			'allowUpperCaseUrlSchemes' => false,
-			'htmlLinkCreator' => static function ($url, $content) {
+			'htmlLinkCreator' => static function ($url) {
 				// Render full url for the link description. Otherwise, potentially malicious query
 				// params might be hidden.
 				return sprintf('<a href="%1$s">%1$s</a>', htmlspecialchars($url));
