@@ -72,14 +72,14 @@ class OutboxService {
 	private $logger;
 
 	public function __construct(IMailTransmission  $transmission,
-								LocalMessageMapper $mapper,
-								AttachmentService  $attachmentService,
-								IEventDispatcher    $eventDispatcher,
-								IMAPClientFactory $clientFactory,
-								IMailManager $mailManager,
-								AccountService $accountService,
-								ITimeFactory $timeFactory,
-								LoggerInterface $logger) {
+		LocalMessageMapper $mapper,
+		AttachmentService  $attachmentService,
+		IEventDispatcher    $eventDispatcher,
+		IMAPClientFactory $clientFactory,
+		IMailManager $mailManager,
+		AccountService $accountService,
+		ITimeFactory $timeFactory,
+		LoggerInterface $logger) {
 		$this->transmission = $transmission;
 		$this->mapper = $mapper;
 		$this->attachmentService = $attachmentService;
@@ -117,7 +117,7 @@ class OutboxService {
 	 * @throws DoesNotExistException
 	 */
 	public function getMessage(int $id, string $userId): LocalMessage {
-		return $this->mapper->findById($id, $userId);
+		return $this->mapper->findById($id, $userId, LocalMessage::TYPE_OUTGOING);
 	}
 
 	/**
@@ -274,4 +274,14 @@ class OutboxService {
 			}
 		}
 	}
+
+	public function convertDraft(LocalMessage $draftMessage, int $sendAt): LocalMessage {
+		if (empty($draftMessage->getRecipients())) {
+			throw new ClientException('Cannot convert message to outbox message without at least one recipient');
+		}
+		$outboxMessage = clone $draftMessage;
+		$outboxMessage->setType(LocalMessage::TYPE_OUTGOING);
+		$outboxMessage->setSendAt($sendAt);
+		return $this->mapper->update($outboxMessage);
+	}
 }
