@@ -26,7 +26,6 @@ declare(strict_types=1);
 namespace OCA\Mail\Service\Search;
 
 class SearchQuery {
-
 	/** @var int|null */
 	private $cursor;
 
@@ -51,9 +50,24 @@ class SearchQuery {
 	/** @var string[] */
 	private $subjects = [];
 
+	/** @var string[] */
+	private $bodies = [];
+
 	/** @var string[] */
 	private $textTokens = [];
 
+	/** @var array[] */
+	private $tags = [];
+
+	/** @var string|null */
+	private $start;
+
+	/** @var string|null */
+	private $end;
+
+	/** @var bool */
+	private $hasAttachments = false;
+
 	/**
 	 * @return int|null
 	 * @psalm-mutation-free
@@ -143,15 +157,83 @@ class SearchQuery {
 	public function addSubject(string $subject): void {
 		$this->subjects[] = $subject;
 	}
+	public function getBodies(): array {
+		return $this->bodies;
+	}
+
+	public function addBody(string $body): void {
+		$this->bodies[] = $body;
+	}
 
 	/**
-	 * @return string[]
+	 * Get tags to search query
+	 *
+	 * @return array
 	 */
-	public function getTextTokens(): array {
-		return $this->textTokens;
+	public function getTags(): array {
+		return $this->tags;
 	}
 
-	public function addTextToken(string $textToken): void {
-		$this->textTokens[] = $textToken;
+	/**
+	 * Set tags to search query
+	 *
+	 * @param array $tags
+	 * @return void
+	 */
+	public function setTags(array $tags): void {
+		$this->tags = $tags;
+	}
+
+	/**
+	 * Get start date to search query
+	 *
+	 * @return string|null
+	 */
+	public function getStart(): ?string {
+		return $this->start;
+	}
+
+	/**
+	 * Set start date to search query
+	 *
+	 * @param string $start
+	 * @return void
+	 */
+	public function setStart(string $start): void {
+		$this->start = $start;
+	}
+
+	/**
+	 * Get start date to search query
+	 *
+	 * @return string|null
+	 */
+	public function getEnd(): ?string {
+		return $this->end;
+	}
+
+	/**
+	 * Set end date to search query
+	 *
+	 * @param string $end
+	 * @return void
+	 */
+	public function setEnd(string $end): void {
+		$this->end = $end;
+	}
+
+	/**
+	 * @return bool|null
+	 * @psalm-mutation-free
+	 */
+	public function getHasAttachments(): ?bool {
+		return $this->hasAttachments;
+	}
+
+	/**
+	 * @param bool $hasAttachments
+	 */
+	public function setHasAttachments(bool $hasAttachments): void {
+		$this->hasAttachments = $hasAttachments;
 	}
 }
